@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2010-2017 Benjamin Kaufmann
+// Copyright (c) 2010-present Benjamin Kaufmann
 //
 // This file is part of Clasp. See http://www.cs.uni-potsdam.de/clasp/
 //
@@ -48,17 +48,11 @@ typedef Asp::PrgDepGraph PrgDepGraph;
 class ConstString {
 public:
 	//! Creates a string from str.
-	/*!
-	 * \note If o is Ownership_t::Acquire (the default), str is copied.
-	 * Otherwise, no copy is made and the lifetime of str shall extend
-	 * past that of the constructed object.
-	 */
-	ConstString(const char* str = "", Ownership_t::Type o = Ownership_t::Acquire);
+	ConstString(const char* str = "");
 	//! Creates a copy of str.
 	ConstString(const StrView& str);
 	ConstString(const ConstString& other);
 	~ConstString();
-	static ConstString fromLiteral(const char* str) { return ConstString(str, Ownership_t::Retain); }
 	ConstString& operator=(const ConstString& rhs);
 	const char* c_str()     const;
 	operator const char* () const { return c_str(); }
@@ -459,7 +453,7 @@ public:
 		uint32 types :  3; /*!< Restrict distribution to these types.    */
 	};
 	static  uint64  mask(uint32 i)             { return uint64(1) << i; }
-	static  uint32  initSet(uint32 sz)         { return (uint64(1) << sz) - 1; }
+	static  uint64  initSet(uint32 sz)         { return sz < 64 ? (uint64(1) << sz) - 1 : UINT64_MAX; }
 	static  bool    inSet(uint64 s, uint32 id) { return (s & mask(id)) != 0; }
 	explicit Distributor(const Policy& p);
 	virtual ~Distributor();
@@ -519,6 +513,7 @@ public:
 	lit_iterator   proj_begin() const { return proj_.begin(); }
 	lit_iterator   proj_end()   const { return proj_.end(); }
 	void           addProject(Literal x);
+	void           clearProject();
 
 	//! Returns the number of output elements, counting each element in a var range.
 	uint32 size()     const;
@@ -621,7 +616,7 @@ public:
 	typedef SingleOwnerPtr<SatPreprocessor>SatPrePtr;
 	typedef SharedMinimizeData*            MinPtr;
 	enum ResizeMode { resize_reserve = 0u, resize_push = 1u, resize_pop = 2u, resize_resize = 3u};
-	enum PreproMode { prepro_preserve_models = 1u, prepro_preserve_shown  = 2u };
+	enum PreproMode { prepro_preserve_models = 1u, prepro_preserve_shown = 2u, prepro_preserve_heuristic = 4u };
 	enum ReportMode { report_default = 0u, report_conflict = 1u };
 	enum SolveMode  { solve_once = 0u, solve_multi = 1u };
 	/*!
@@ -647,6 +642,8 @@ public:
 	void       setPreserveModels(bool b = true) { setPreproMode(prepro_preserve_models, b); }
 	//! If b is true, excludes all shown variables from variable elimination.
 	void       setPreserveShown(bool b = true)  { setPreproMode(prepro_preserve_shown, b); }
+	//! If b is true, excludes all variables with domain heuristic modifications from variable elimination.
+	void       setPreserveHeuristic(bool b = true) { setPreproMode(prepro_preserve_heuristic, b); }
 
 	//! Adds an additional solver to this object and returns it.
 	Solver&    pushSolver();
@@ -676,6 +673,8 @@ public:
 	uint32     concurrency()        const { return share_.count; }
 	bool       preserveModels()     const { return (share_.satPreM & prepro_preserve_models) != 0; }
 	bool       preserveShown()      const { return (share_.satPreM & prepro_preserve_shown) != 0; }
+	bool       preserveHeuristic()  const { return (share_.satPreM & prepro_preserve_heuristic) != 0; }
+	uint32     defaultDomPref()     const;
 	//! Returns whether physical sharing is enabled for constraints of type t.
 	bool       physicalShare(ConstraintType t) const { return (share_.shareM & (1 + (t != Constraint_t::Static))) != 0; }
 	//! Returns whether physical sharing of problem constraints is enabled.
@@ -699,7 +698,7 @@ public:
 	bool       isShared()           const { return frozen() && concurrency() > 1; }
 	//! Returns whether the problem is more than a simple CNF.
 	bool       isExtended()         const { return stats_.vars.frozen != 0; }
-	//! Returns whether this object has a solver associcated with the given id.
+	//! Returns whether this object has a solver associated with the given id.
 	bool       hasSolver(uint32 id) const { return id < solvers_.size(); }
 	//! Returns the master solver associated with this object.
 	Solver*    master()             const { return solver(0);    }
@@ -942,9 +941,8 @@ private:
 		uint32 solveM  : 1;        //   solve mode
 		uint32 frozen  : 1;        //   is adding of problem constraints allowed?
 		uint32 seed    : 1;        //   set seed of new solvers
-		uint32 satPreM : 2;        //   preprocessing mode
+		uint32 satPreM : 3;        //   preprocessing mode
 		uint32 report  : 2;        //   report mode
-		uint32 reserved: 1;
 		Share() : count(1), winner(0), shareM((uint32)ContextParams::share_auto), shortM(0), solveM(0), frozen(0), seed(0), satPreM(0), report(0) {}
 	}            share_;
 };
