@@ -197,7 +197,7 @@ TEST_CASE("Text writer ", "[text]") {
 	SECTION("simple fact") {
 		input << "x1.";
 		read(prg, input);
-		REQUIRE(output.str() == "x_1.\n");
+		REQUIRE(output.str() == "x_1.\n#show.\n");
 	}
 	SECTION("named fact") {
 		input << "x1.\n#output foo : x1.";
@@ -207,109 +207,316 @@ TEST_CASE("Text writer ", "[text]") {
 	SECTION("simple choice") {
 		input << "{x1,x2}.\n#output foo : x1.";
 		read(prg, input);
-		REQUIRE(output.str() == "{foo;x_2}.\n");
+		REQUIRE(output.str() == "{foo;x_2}.\n#show foo/0.\n");
+	}
+	SECTION("empty choice") {
+		input << "{}.";
+		read(prg, input);
+		REQUIRE(output.str() == "{}.\n");
 	}
 	SECTION("integrity constraint") {
 		input << ":- x1,x2.\n#output foo : x1.";
 		read(prg, input);
-		REQUIRE(output.str() == ":- foo, x_2.\n");
+		REQUIRE(output.str() == ":- foo, x_2.\n#show foo/0.\n");
 	}
 	SECTION("empty integrity constraint") {
 		input << ":-.";
 		read(prg, input);
 		REQUIRE(output.str() == ":- .\n");
 	}
+	SECTION("classical negation") {
+		Atom_t head(1);
+		Lit_t cond(1);
+		out.beginStep();
+		out.rule(Head_t::Choice, toSpan(&head, 1), {});
+		out.output(toSpan("-a"), toSpan(&cond, 1));
+		out.output(toSpan("-8"), toSpan(&cond, 1));
+		out.endStep();
+		REQUIRE(output.str() == "{-a}.\n#show -8 : -a.\n");
+	}
+	SECTION("classical negation tricky") {
+		std::vector<Atom_t> head{1,2};
+		Lit_t cond1(1);
+		Lit_t cond2(2);
+		out.beginStep();
+		out.rule(Head_t::Choice, toSpan(head), {});
+		out.output(toSpan("-a"), toSpan(&cond1, 1));
+		out.output(toSpan("x_1"), toSpan(&cond2, 1));
+		out.endStep();
+		REQUIRE(output.str() == "{-a;x_2}.\n#show x_1 : x_2.\n#show -a/0.\n");
+	}
 	SECTION("basic rule") {
 		input << "x1 :- x2, not x3, x4.\n#output foo : x1.\n#output bar : x3.";
 		read(prg, input);
-		REQUIRE(output.str() == "foo :- x_2, not bar, x_4.\n");
+		REQUIRE(output.str() == "foo :- x_2, not bar, x_4.\n#show foo/0.\n#show bar/0.\n");
 	}
 	SECTION("choice rule") {
 		input << "{x1,x2} :- not x3, x4.\n#output foo : x1.\n#output bar : x3.";
 		read(prg, input);
-		REQUIRE(output.str() == "{foo;x_2} :- not bar, x_4.\n");
+		REQUIRE(output.str() == "{foo;x_2} :- not bar, x_4.\n#show foo/0.\n#show bar/0.\n");
 	}
 	SECTION("disjunctive rule") {
 		input << "x1;x2 :- not x3, x4.\n#output foo : x1.\n#output bar : x3.";
 		read(prg, input);
-		REQUIRE(output.str() == "foo|x_2 :- not bar, x_4.\n");
+		REQUIRE(output.str() == "foo|x_2 :- not bar, x_4.\n#show foo/0.\n#show bar/0.\n");
 	}
 	SECTION("cardinality rule") {
 		input << "x1;x2 :- 1{not x3, x4}.\n#output foo : x1.\n#output bar : x3.";
 		read(prg, input);
-		REQUIRE(output.str() == "foo|x_2 :- 1{not bar; x_4}.\n");
+		REQUIRE(output.str() == "foo|x_2 :- 1 #count{1 : not bar; 2 : x_4}.\n#show foo/0.\n#show bar/0.\n");
 	}
 	SECTION("sum rule") {
 		input << "x1;x2 :- 3{not x3=2, x4, x5=1,x6=2}.\n#output foo : x1.\n#output bar : x3.";
 		read(prg, input);
-		REQUIRE(output.str() == "foo|x_2 :- 3{not bar=2; x_4=1; x_5=1; x_6=2}.\n");
+		REQUIRE(output.str() == "foo|x_2 :- 3 #sum{2,1 : not bar; 1,2 : x_4; 1,3 : x_5; 2,4 : x_6}.\n#show foo/0.\n#show bar/0.\n");
 	}
 	SECTION("convert sum rule to cardinality rule") {
 		input << "x1;x2 :- 3{not x3=2, x4=2, x5=2,x6=2}.\n#output foo : x1.\n#output bar : x3.";
 		read(prg, input);
-		REQUIRE(output.str() == "foo|x_2 :- 2{not bar; x_4; x_5; x_6}.\n");
+		REQUIRE(output.str() == "foo|x_2 :- 2 #count{1 : not bar; 2 : x_4; 3 : x_5; 4 : x_6}.\n#show foo/0.\n#show bar/0.\n");
+	}
+	SECTION("convert sum rule with duplicate to cardinality rule") {
+		input << "x2 :- 3{x3=1, x4=1, x5=1,x3=1}.\n";
+		read(prg, input);
+		REQUIRE(output.str() == "x_2 :- 3 #count{1 : x_3; 2 : x_4; 3 : x_5; 4 : x_3}.\n#show.\n");
 	}
 	SECTION("minimize rule") {
 		input << "#minimize{x1,x2=2,x3}.\n#minimize{not x1=3,not x2,not x3}@1.";
 		read(prg, input);
-		REQUIRE(output.str() == "#minimize{x_1=1; x_2=2; x_3=1}@0.\n#minimize{not x_1=3; not x_2=1; not x_3=1}@1.\n");
+		REQUIRE(output.str() ==
+		        "#minimize{1@0,1 : x_1; 2@0,2 : x_2; 1@0,3 : x_3}.\n#minimize{3@1,1 : not x_1; 1@1,2 : not "
+		        "x_2; 1@1,3 : not x_3}.\n#show.\n");
 	}
 	SECTION("output statements") {
 		input << "{x1;x2}.\n#output foo.\n#output bar : x1.\n#output \"Hello World\" : x2, not x1.";
 		read(prg, input);
-		REQUIRE(output.str() == "{bar;x_2}.\n#show foo.\n#show \"Hello World\" : x_2, not bar.\n");
+		REQUIRE(output.str() == "{bar;x_2}.\n#show foo.\n#show \"Hello World\" : x_2, not bar.\n"
+								"#show bar/0.\n");
+	}
+	SECTION("duplicate output condition") {
+		input << "{a}.\n#output x:a.\n#output y:a.\n";
+		read(prg, input);
+		REQUIRE(output.str() == "{x_1}.\n#show x : x_1.\n#show y : x_1.\n#show.\n");
+	}
+	SECTION("bogus duplicate output condition") {
+		input << "{a}.\n#output x:a.\n#output x:a.\n";
+		read(prg, input);
+		REQUIRE(output.str() == "{x}.\n");
+	}
+	SECTION("duplicate output term") {
+		input << "{x1;x2}.\n";
+		SECTION("simple") {
+			input << "#output a:x1.\n#output a:x2.\n";
+			read(prg, input);
+			REQUIRE(output.str() == "{x_1;x_2}.\n#show a : x_1.\n#show a : x_2.\n#show.\n");
+		}
+		SECTION("complex") {
+			input << "#output a:x1.\n#output a:x1,x2.\n";
+			read(prg, input);
+			REQUIRE(output.str() == "{a;x_2}.\n#show a : a, x_2.\n#show a/0.\n");
+		}
+		SECTION("complex reversed") {
+			input << "#output a:x1,x2.\n#output a:x1.\n";
+			read(prg, input);
+			REQUIRE(output.str() == "{a;x_2}.\n#show a : a, x_2.\n#show a/0.\n");
+		}
+		SECTION("duplicate condition first") {
+			input << "#output a:x1.\n#output b:x1.\n#output a:x2.\n";
+			read(prg, input);
+			REQUIRE(output.str() == "{x_1;x_2}.\n#show a : x_1.\n#show b : x_1.\n#show a : x_2.\n#show.\n");
+		}
+		SECTION("duplicate condition all") {
+			input << "#output a:x1.\n#output b:x1.\n#output a:x2.\n#output f:x2.\n";
+			read(prg, input);
+			REQUIRE(output.str() == "{x_1;x_2}.\n#show a : x_1.\n#show b : x_1.\n#show a : x_2.\n#show f : x_2.\n#show.\n");
+		}
+	}
+	SECTION("implicit show") {
+		input << "{a;b}. #output a:a.\n#output b:b.\n";
+		read(prg, input);
+		REQUIRE(output.str() == "{a;b}.\n");
+	}
+	SECTION("explicit show") {
+		input << "{a;b}.\n";
+		SECTION("empty") {
+			read(prg, input);
+			REQUIRE(output.str() == "{x_1;x_2}.\n#show.\n");
+		}
+		SECTION("one") {
+			input << "#output a:a.\n";
+			read(prg, input);
+			REQUIRE(output.str() == "{a;x_2}.\n#show a/0.\n");
+		}
+		SECTION("duplicate one") {
+			input << "#output a:b.\n#output b:b.\n";
+			read(prg, input);
+			REQUIRE(output.str() == "{x_1;x_2}.\n#show a : x_2.\n#show b : x_2.\n#show.\n");
+		}
+		SECTION("duplicate two") {
+			input << "#output b:b.\n#output a:b.\n";
+			read(prg, input);
+			REQUIRE(output.str() == "{x_1;x_2}.\n#show b : x_2.\n#show a : x_2.\n#show.\n");
+		}
+		SECTION("duplicate three") {
+			input << "#output a:a.\n#output b:b.\n#output c:b.\n";
+			read(prg, input);
+			REQUIRE(output.str() == "{a;x_2}.\n#show b : x_2.\n#show c : x_2.\n#show a/0.\n");
+		}
+	}
+	SECTION("output reserved name") {
+		input << "{a;b}.\n";
+		SECTION("all") {
+			SECTION("match") {
+				input << "#output x_2:b.\n#output x_1:a.";
+				read(prg, input);
+				REQUIRE(output.str() == "{x_1;x_2}.\n#show x_2 : x_2.\n#show x_1 : x_1.\n#show.\n");
+			}
+			SECTION("mismatch") {
+				input << "#output x_2:a.\n#output x_1:b.";
+				read(prg, input);
+				REQUIRE(output.str() == "{x_1;x_2}.\n#show x_2 : x_1.\n#show x_1 : x_2.\n#show.\n");
+			}
+		}
+		SECTION("some") {
+			SECTION("match") {
+				input << "#output x_2:b.";
+				read(prg, input);
+				REQUIRE(output.str() == "{x_1;x_2}.\n#show x_2 : x_2.\n#show.\n");
+			}
+			SECTION("mismatch") {
+				input << "#output x_2:a.";
+				read(prg, input);
+				REQUIRE(output.str() == "{x_1;x_2}.\n#show x_2 : x_1.\n#show.\n");
+			}
+		}
+		SECTION("incremental handled as some") {
+			out.initProgram(true);
+			out.beginStep();
+			std::vector<Atom_t> head;
+			std::vector<Lit_t>  cond;
+			out.rule(Head_t::Choice, toSpan(head = {1, 2}), {}); // {1;2}.
+			out.output(toSpan("x_3"), toSpan(cond = {1}));       // #show x_3 : 1.
+			out.output(toSpan("x_2"), toSpan(cond = {2}));       // #show x_2 : 2.
+			out.endStep();
+			REQUIRE(output.str() == "% #program base.\n"
+			                        "{x_1;x_2}.\n"
+			                        "#show x_3 : x_1.\n"
+			                        "#show x_2 : x_2.\n"
+			                        "#show.\n");
+			output.str("");
+			out.beginStep();
+			out.rule(Head_t::Choice, toSpan(head = {3}), toSpan(cond = {1, 2})); // {3} :- 1, 2.
+			out.endStep();
+			REQUIRE(output.str() == "% #program step(1).\n"
+			                        "{x_3} :- x_1, x_2.\n");
+		}
+	}
+	SECTION("output duplicate reserved") {
+		out.initProgram(false);
+		out.beginStep();
+		Atom_t a  = 1;
+		auto   al = lit(a);
+		out.rule(Head_t::Choice, {&a, 1}, {});     // {x_1}.
+		out.output(toSpan("x_1"), toSpan(&al, 1)); // #show x_1 : x_1. NOTE: uses reserved name "x_1"
+		out.output(toSpan("a"), toSpan(&al, 1));   // #show a : x_1.
+		SECTION("unique alternative") {
+			out.endStep();
+			REQUIRE(output.str() == "{x_1}.\n#show x_1 : x_1.\n#show a : x_1.\n#show.\n");
+		}
+		SECTION("two alternatives") {
+			out.output(toSpan("b"), toSpan(&al, 1)); // #show b : x_1.
+			out.endStep();
+			REQUIRE(output.str() == "{x_1}.\n#show x_1 : x_1.\n#show a : x_1.\n#show b : x_1.\n#show.\n");
+		}
+	}
+	SECTION("output predicate") {
+		std::vector<Atom_t> head;
+		std::vector<Lit_t>  cond;
+		out.initProgram(false);
+		out.beginStep();
+		out.rule(Head_t::Choice, toSpan(head = {1, 2, 3, 4, 5}), {});
+		out.output(toSpan("a"), toSpan(cond = {1}));
+		out.output(toSpan("a(1,2,3,4,5,6,7,8,9,10,11,12)"), toSpan(cond = {2}));
+		out.output(toSpan("b(t(1,2,3))"), toSpan(cond = {3}));
+		out.output(toSpan("b()"), toSpan(cond = {4}));
+		out.endStep();
+		REQUIRE(output.str() == "{a;a(1,2,3,4,5,6,7,8,9,10,11,12);b(t(1,2,3));b;x_5}.\n#show a/0.\n#show "
+		                        "a/12.\n#show b/1.\n#show b/0.\n");
+	}
+	SECTION("output invalid predicate") {
+		std::vector<Atom_t> head;
+		std::vector<Lit_t>  cond;
+		out.initProgram(false);
+		out.beginStep();
+		out.rule(Head_t::Choice, toSpan(head = {1}), {});
+		SECTION("missing close") { REQUIRE_THROWS_AS(out.output(toSpan("a("), toSpan(cond = {1})), std::logic_error); }
+		SECTION("missing arg") { REQUIRE_THROWS_AS(out.output(toSpan("a(1,"), toSpan(cond = {1})), std::logic_error); }
+		SECTION("missing arg on close") { REQUIRE_THROWS_AS(out.output(toSpan("a(1,)"), toSpan(cond = {1})), std::logic_error); }
+		SECTION("empty arg") { REQUIRE_THROWS_AS(out.output(toSpan("a(1,,2)"), toSpan(cond = {1})), std::logic_error); }
+		SECTION("unmatched close") { REQUIRE_THROWS_AS(out.output(toSpan("a(x()"), toSpan(cond = {1})), std::logic_error); }
+		SECTION("empty arg 2") { REQUIRE_THROWS_AS(out.output(toSpan("b(,)"), toSpan(cond = {1})), std::logic_error); }
 	}
 	SECTION("write external - ") {
 		SECTION("default") {
 			input << "#external x1.";
 			read(prg, input);
-			REQUIRE(output.str() == "#external x_1.\n");
+			REQUIRE(output.str() == "#external x_1.\n#show.\n");
 		}
 		SECTION("false is default") {
 			input << "#external x1. [false]";
 			read(prg, input);
-			REQUIRE(output.str() == "#external x_1.\n");
+			REQUIRE(output.str() == "#external x_1.\n#show.\n");
 		}
 		SECTION("with value") {
 			input << "#external x1. [true]";
 			input << "#external x2. [free]";
 			input << "#external x3. [release]";
 			read(prg, input);
-			REQUIRE(output.str() == "#external x_1. [true]\n#external x_2. [free]\n#external x_3. [release]\n");
+			REQUIRE(output.str() == "#external x_1. [true]\n#external x_2. [free]\n#external x_3. [release]\n#show.\n");
 		}
 	}
+	SECTION("empty assumption directive") {
+		input << "#assume{}.";
+		read(prg, input);
+		REQUIRE(output.str() == "#assume{}.\n");
+	}
 	SECTION("assumption directive") {
 		input << "#assume{x1,not x2,x3}.";
 		read(prg, input);
-		REQUIRE(output.str() == "#assume{x_1, not x_2, x_3}.\n");
+		REQUIRE(output.str() == "#assume{x_1, not x_2, x_3}.\n#show.\n");
+	}
+	SECTION("empty projection directive") {
+		input << "#project{}.";
+		read(prg, input);
+		REQUIRE(output.str() == "#project{}.\n");
 	}
 	SECTION("projection directive") {
 		input << "#project{x1,x2,x3}.";
 		read(prg, input);
-		REQUIRE(output.str() == "#project{x_1, x_2, x_3}.\n");
+		REQUIRE(output.str() == "#project{x_1, x_2, x_3}.\n#show.\n");
 	}
 	SECTION("edge directive") {
 		input << "#edge (0,1) : x1, not x2.";
 		input << "#edge (1,0).";
 		read(prg, input);
-		REQUIRE(output.str() == "#edge(0,1) : x_1, not x_2.\n#edge(1,0).\n");
+		REQUIRE(output.str() == "#edge(0,1) : x_1, not x_2.\n#edge(1,0).\n#show.\n");
 	}
 
 	SECTION("heuristic directive -") {
 		SECTION("simple") {
 			input << "#heuristic a. [1,true]";
 			read(prg, input);
-			REQUIRE(output.str() == "#heuristic x_1. [1, true]\n");
+			REQUIRE(output.str() == "#heuristic x_1. [1, true]\n#show.\n");
 		}
 		SECTION("simple with priority") {
 			input << "#heuristic a. [1@2,true]";
 			read(prg, input);
-			REQUIRE(output.str() == "#heuristic x_1. [1@2, true]\n");
+			REQUIRE(output.str() == "#heuristic x_1. [1@2, true]\n#show.\n");
 		}
 		SECTION("with condition") {
 			input << "#heuristic a : b, not c. [1@2,true]";
 			read(prg, input);
-			REQUIRE(output.str() == "#heuristic x_1 : x_2, not x_3. [1@2, true]\n");
+			REQUIRE(output.str() == "#heuristic x_1 : x_2, not x_3. [1@2, true]\n#show.\n");
 		}
 	}
 	SECTION("incremental program") {
@@ -328,11 +535,32 @@ TEST_CASE("Text writer ", "[text]") {
 			"% #program base.\n"
 			"{a(1);x_2}.\n"
 			"#external x_3.\n"
+		        "#show a/1.\n"
 			"% #program step(1).\n"
 			"x_3 :- a(1).\n"
 			"% #program step(2).\n"
 			"x_4 :- x_2, not x_3.\n");
 	}
+	SECTION("incremental output") {
+		input << "#incremental.\n";
+		input << "{x1;x2}.";
+		input << "#output f : x2.";
+		input << "#step.";
+		input << "#output foo : x1.";
+		input << "x3 :- x1, x2.";
+		input << "#output f : x3.";
+		input << "#output nX2 : x2.";
+		read(prg, input);
+		prg.parse();
+		REQUIRE(output.str() == "% #program base.\n"
+		                        "{x_1;f}.\n"
+		                        "#show f/0.\n"
+		                        "% #program step(1).\n"
+		                        "#show foo : x_1.\n"
+		                        "x_3 :- x_1, f.\n"
+		                        "#show f : x_3.\n"
+		                        "#show nX2 : f.\n");
+	}
 }
 
 TEST_CASE("Text writer writes theory", "[text]") {
@@ -398,7 +626,14 @@ TEST_CASE("Text writer writes theory", "[text]") {
 		out.theoryElement(1, Potassco::toSpan(ids = {2}), Potassco::toSpan<Lit_t>());
 		out.theoryAtom(1, 0, Potassco::toSpan(ids = {0, 1}));
 		out.endStep();
-		REQUIRE(output.str() == "x_2 :- &atom{x, y; y}.\n");
+		REQUIRE(output.str() == "x_2 :- &atom{x, y; y}.\n#show.\n");
+	}
+	SECTION("Fail on duplicate theory atom") {
+		out.theoryTerm(0, Potassco::toSpan("t"));
+		out.theoryTerm(1, Potassco::toSpan("x"));
+		out.theoryAtom(1, 0, {});
+		out.theoryAtom(1, 1, {});
+		REQUIRE_THROWS_AS(out.endStep(), std::logic_error);
 	}
 	SECTION("Theory element with condition") {
 		std::vector<Atom_t> head;
@@ -406,18 +641,35 @@ TEST_CASE("Text writer writes theory", "[text]") {
 		std::vector<Lit_t> body;
 		out.rule(Head_t::Choice, toSpan(head = {1, 2}), toSpan<Lit_t>());
 		out.rule(Head_t::Disjunctive, toSpan(head = {4}), toSpan(body = {3}));
-		out.output(toSpan("y"), toSpan(body = {1}));
-		out.output(toSpan("z"), toSpan(body = {2}));
 		out.theoryTerm(0, Potassco::toSpan("atom"));
 		out.theoryTerm(1, Potassco::toSpan("elem"));
 		out.theoryTerm(2, Potassco::toSpan("p"));
 		out.theoryElement(0, Potassco::toSpan(ids = {1}), Potassco::toSpan(body = {1, -2}));
 		out.theoryElement(1, Potassco::toSpan(ids = {2}), Potassco::toSpan(body = {1}));
 		out.theoryAtom(3, 0, Potassco::toSpan(ids = {0, 1}));
-		out.endStep();
-		REQUIRE(output.str() ==
-			"{y;z}.\n"
-			"x_4 :- &atom{elem : y, not z; p : y}.\n");
+		SECTION("default") {
+			out.endStep();
+			REQUIRE(output.str() == "{x_1;x_2}.\n"
+			                        "x_4 :- &atom{elem : x_1, not x_2; p : x_1}.\n#show.\n");
+		}
+		SECTION("override output") {
+			out.output(Potassco::toSpan("foo"), Potassco::toSpan((body = {3})));
+			SECTION("once") {
+				out.endStep();
+				// Ensure that we don't use "foo" for x_3.
+				REQUIRE(output.str() == "{x_1;x_2}.\n"
+				                        "x_4 :- &atom{elem : x_1, not x_2; p : x_1}.\n"
+				                        "#show foo : &atom{elem : x_1, not x_2; p : x_1}.\n#show.\n");
+			}
+			SECTION("twice") {
+				out.output(Potassco::toSpan("bar"), Potassco::toSpan((body = {3})));
+				out.endStep();
+				REQUIRE(output.str() == "{x_1;x_2}.\n"
+				                        "x_4 :- &atom{elem : x_1, not x_2; p : x_1}.\n"
+				                        "#show foo : &atom{elem : x_1, not x_2; p : x_1}.\n"
+				                        "#show bar : &atom{elem : x_1, not x_2; p : x_1}.\n#show.\n");
+			}
+		}
 	}
 	SECTION("write complex atom incrementally") {
 		out.initProgram(true);
@@ -450,9 +702,26 @@ TEST_CASE("Text writer writes theory", "[text]") {
 		out.theoryElement(0, Potassco::toSpan(ids = {14}), Potassco::toSpan<Lit_t>());
 		out.theoryAtom(0, 0, Potassco::toSpan(ids = {0}), 2, 1);
 		out.endStep();
-		REQUIRE(output.str() ==
-			"% #program step(1).\n"
-			"&diff{end(2) - start(2)} <= 600.\n");
+		REQUIRE(output.str() == "% #program step(1).\n&diff{end(2) - start(2)} <= 600.\n");
+	}
+	SECTION("invalid increment") {
+		out.initProgram(true);
+		out.beginStep();
+		out.theoryTerm(0, Potassco::toSpan("t"));
+		std::vector<Atom_t> head;
+		std::vector<Lit_t>  body;
+		out.rule(Head_t::Choice, Potassco::toSpan((head = {1, 2})), {});
+		out.output(Potassco::toSpan("a"), Potassco::toSpan((body = {1})));
+		out.output(Potassco::toSpan("b"), Potassco::toSpan((body = {2})));
+		out.endStep();
+		REQUIRE(output.str() == "% #program base.\n"
+		                        "{a;b}.\n");
+
+		output.str("");
+		out.beginStep();
+		out.theoryAtom(2, 0, {});
+		out.rule(Head_t::Choice, Potassco::toSpan((head = {4})), Potassco::toSpan((body = {2})));
+		REQUIRE_THROWS_AS(out.endStep(), std::logic_error);
 	}
 }
 }}}
