@@ -231,6 +231,13 @@ void ClingoPropagator::undoLevel(Solver& s) {
 	POTASSCO_REQUIRE(s.decisionLevel() == level_, "Invalid undo");
 	uint32 beg = undo_.back();
 	undo_.pop_back();
+
+	if (test_bit(beg, CHECK_BIT) && call_->undoMode() == ClingoPropagatorUndo_t::Always) {
+		assert(beg >= prop_);
+		Potassco::LitSpan change = Potassco::toSpan<Potassco::Lit_t>();
+		ScopedLock(call_->lock(), call_->propagator(), Inc(epoch_))->undo(Control(*this, s), change);
+	}
+
 	if (prop_ > beg) {
 		Potassco::LitSpan change = Potassco::toSpan(&trail_[0] + beg, prop_ - beg);
 		ScopedLock(call_->lock(), call_->propagator(), Inc(epoch_))->undo(Control(*this, s), change);
@@ -318,15 +325,15 @@ bool ClingoPropagator::addClause(Solver& s, uint32 st) {
 	Literal w0 = clause.size > 0 ? clause.lits[0] : lit_false();
 	Literal w1 = clause.size > 1 ? clause.lits[1] : lit_false();
 	uint32  cs = ClauseCreator::status(s, clause);
+	bool local = (todo_.flags & ClauseCreator::clause_no_add) != 0;
 	if (cs & (ClauseCreator::status_unit|ClauseCreator::status_unsat)) {
-		uint32 dl = (cs & ClauseCreator::status_unsat) ? s.level(w0.var()) : s.level(w1.var());
+		uint32 dl = (cs & ClauseCreator::status_unsat) && !local ? s.level(w0.var()) : s.level(w1.var());
 		if (dl < s.decisionLevel() && s.isUndoLevel()) {
 			if ((st & state_ctrl) != 0u) { return false; }
 			if ((st & state_prop) != 0u) { ClingoPropagator::reset(); cancelPropagation(); }
 			s.undoUntil(dl);
 		}
 	}
-	bool local = (todo_.flags & ClauseCreator::clause_no_add) != 0;
 	if (!s.isFalse(w0) || local || s.force(w0, this)) {
 		ClauseCreator::Result res = ClauseCreator::create(s, clause, todo_.flags);
 		if (res.local && local) { db_.push_back(res.local); }
@@ -417,7 +424,7 @@ struct ClingoPropagatorInit::History : POTASSCO_EXT_NS::unordered_map<Potassco::
 };
 
 ClingoPropagatorInit::ClingoPropagatorInit(Potassco::AbstractPropagator& cb, ClingoPropagatorLock* lock, CheckType m)
-	: prop_(&cb), lock_(lock), history_(0), step_(1), check_(m) {
+	: prop_(&cb), lock_(lock), history_(0), step_(1), check_(m), undo_(ClingoPropagatorUndo_t::Default) {
 }
 ClingoPropagatorInit::~ClingoPropagatorInit()         { delete history_; }
 bool ClingoPropagatorInit::applyConfig(Solver& s)     { return s.addPost(new ClingoPropagator(this)); }
@@ -504,6 +511,10 @@ void ClingoPropagatorInit::enableClingoPropagatorCheck(CheckType checkMode) {
 	check_ = checkMode;
 }
 
+void ClingoPropagatorInit::enableClingoPropagatorUndo(UndoType undoMode) {
+	undo_ = undoMode;
+}
+
 void ClingoPropagatorInit::enableHistory(bool b) {
 	if (!b)             { delete history_; history_ = 0; }
 	else if (!history_) { history_ = new History(); }
