@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2014-2017 Benjamin Kaufmann
+// Copyright (c) 2014-present Benjamin Kaufmann
 //
 // This file is part of Clasp. See http://www.cs.uni-potsdam.de/clasp/
 //
@@ -33,6 +33,7 @@
 #include <potassco/theory_data.h>
 #include <potassco/aspif.h>
 #include <potassco/smodels.h>
+#include POTASSCO_EXT_INCLUDE(unordered_map)
 #include <stdio.h>
 #include <stdlib.h>
 #include <limits.h>
@@ -52,7 +53,7 @@ ProblemType detectProblemType(std::istream& in) {
 		in.get();
 		++line;
 	}
-	throw std::logic_error("bad input stream");
+	POTASSCO_REQUIRE(false, "bad input stream");
 }
 /////////////////////////////////////////////////////////////////////////////////////////
 // ProgramParser
@@ -293,16 +294,17 @@ bool DimacsReader::doAttach(bool& inc) {
 	if (!accept(peek(false))) { return false; }
 	skipLines('c');
 	require(match("p "), "missing problem line");
-	wcnf_ = match("w");
-	require(match("cnf", false), "unrecognized format, [w]cnf expected");
-	if (stream()->peek() == '+') { stream()->get(); }
+	bool knf = match("knf");
+	wcnf_ = !knf && match("w");
+	require(knf || match("cnf", false), "unrecognized format, [w]cnf expected");
+	plus_ = !knf && match("+", false);
 	require(stream()->get() == ' ', "invalid problem line: expected ' ' after format");
 	numVar_     = matchPos(ProgramParser::VAR_MAX, "#vars expected");
 	uint32 numC = matchPos("#clauses expected");
 	wsum_t cw   = 0;
-	while (stream()->peek() == ' ')  { stream()->get(); };
+	while (stream()->peek() == ' ')  { stream()->get(); }
 	if (wcnf_ && peek(false) != '\n'){ stream()->match(cw); }
-	while (stream()->peek() == ' ')  { stream()->get(); };
+	while (stream()->peek() == ' ')  { stream()->get(); }
 	require(stream()->get() == '\n', "invalid extra characters in problem line");
 	program_->prepareProblem(numVar_, cw, numC);
 	if (options.anyOf(ParserOptions::parse_full)) {
@@ -313,23 +315,30 @@ bool DimacsReader::doAttach(bool& inc) {
 bool DimacsReader::doParse() {
 	LitVec cc; WeightLitVec wlc;
 	const bool  wcnf = wcnf_;
+	const bool  card = plus_;
 	const int64 maxV = static_cast<int64>(numVar_);
-	for (int64 cw = (int64)options.isEnabled(ParserOptions::parse_maxsat), lit = 0; skipLines('c') && peek(true); lit = 0, cc.clear()) {
+	for (int64 cw = (int64)options.isEnabled(ParserOptions::parse_maxsat), lit = 0; skipLines('c') && peek(true); cc.clear()) {
 		if (wcnf) { require(stream()->match(cw) && cw > 0, "wcnf: positive clause weight expected"); }
-		while (stream()->match(lit) && lit != 0) {
-			require(lit >= -maxV && lit <= maxV, "invalid variable in clause");
-			cc.push_back(toLit(static_cast<int32>(lit)));
-		}
-		if (lit == 0) { program_->addClause(cc, cw); }
-		else {
-			require(!wcnf, "invalid character in clause");
-			const int  sign = match("<= ") ? -1 : int(require(match(">= "), "invalid constraint operator"));
-			const int bound = matchInt(CLASP_WEIGHT_T_MIN, CLASP_WEIGHT_T_MAX, "invalid constraint bound");
-			wlc.clear();
-			for (LitVec::const_iterator it = cc.begin(), end = cc.end(); it != end; ++it) {
-				wlc.push_back(WeightLiteral(*it, sign));
+		if (!card || peek(wcnf) != 'w') {
+			for (lit = -1; stream()->match(lit) && lit != 0;) {
+				require(lit >= -maxV && lit <= maxV, "invalid variable in clause");
+				cc.push_back(toLit(static_cast<int32>(lit)));
 			}
-			program_->addConstraint(wlc, bound * sign);
+			if      (lit == 0) { program_->addClause(cc, cw); }
+			else if (card)     {
+				wlc.clear();
+				for (LitVec::const_iterator it = cc.begin(), end = cc.end(); it != end; ++it) {
+					wlc.push_back(WeightLiteral(*it, 1));
+				}
+				parseConstraintRhs(wlc);
+			}
+			else {
+				require(cc.empty() && !wcnf_ && match("k "), "invalid character in clause - '0' expected");
+				parseAtLeastK(wlc, maxV);
+			}
+		}
+		else {
+			parsePbConstraint(wlc, maxV);
 		}
 	}
 	return require(!more(), "unrecognized format");
@@ -340,6 +349,45 @@ void DimacsReader::addObjective(const WeightLitVec& vec) {
 void DimacsReader::addAssumption(Literal x) {
 	program_->addAssumption(x);
 }
+void DimacsReader::parseConstraintRhs(WeightLitVec& lhs) {
+	char c = stream()->get();
+	require((c == '<' || c == '>') && match("= "), "constraint operator '<=' or '>=' expected");
+	int64_t bound;
+	require(stream()->match(bound), "constraint bound expected");
+	require(bound >= CLASP_WEIGHT_T_MIN && bound <= CLASP_WEIGHT_T_MAX, "invalid constraint bound");
+	if (c == '<') {
+		bound *= -1;
+		for (WeightLitVec::iterator it = lhs.begin(), end = lhs.end(); it != end; ++it) {
+			it->second *= -1;
+		}
+	}
+	program_->addConstraint(lhs, static_cast<weight_t>(bound));
+}
+void DimacsReader::parsePbConstraint(WeightLitVec& constraint, int64_t maxV) {
+	constraint.clear();
+	require(match("w"), "'w' expected");
+	for (int64_t weight, lit; stream()->match(weight); ) {
+		require(weight >= CLASP_WEIGHT_T_MIN && weight <= CLASP_WEIGHT_T_MAX, "invalid constraint weight");
+		match("*");
+		require(stream()->match(lit), "literal expected");
+		require(lit >= -maxV && lit <= maxV && lit != 0, "invalid variable in constraint");
+		constraint.push_back(WeightLiteral(toLit(static_cast<int32>(lit)), static_cast<weight_t>(weight)));
+	}
+	parseConstraintRhs(constraint);
+}
+void DimacsReader::parseAtLeastK(WeightLitVec& scratch, int64_t maxV) {
+	scratch.clear();
+	int64 k;
+	require(stream()->match(k) && k >= 0 && k <= CLASP_WEIGHT_T_MAX, "invalid at-least-k constraint");
+	for (int64 lit;;) {
+		require(stream()->match(lit) && lit >= -maxV && lit <= maxV, "invalid variable in at-least-k constraint");
+		if (lit == 0) {
+			program_->addConstraint(scratch, static_cast<weight_t>(k));
+			return;
+		}
+		scratch.push_back(WeightLiteral(toLit(static_cast<int32>(lit)), 1));
+	}
+}
 /////////////////////////////////////////////////////////////////////////////////////////
 // OpbReader
 /////////////////////////////////////////////////////////////////////////////////////////
