@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2006-2017 Benjamin Kaufmann
+// Copyright (c) 2006-present Benjamin Kaufmann
 //
 // This file is part of Clasp. See http://www.cs.uni-potsdam.de/clasp/
 //
@@ -247,6 +247,38 @@ TEST_CASE("Model-guided minimize", "[constraint][asp]") {
 		REQUIRE((newMin->shared()->weights[0].weight == 1));
 		REQUIRE((newMin->shared()->weights[1].weight == -5));
 	}
+	SECTION("testSparseCompare") {
+		mb.add(0, WeightLiteral(b, 1));
+		mb.add(1, WeightLiteral(a, 1));
+		mb.add(2, WeightLiteral(c, -1));
+		mb.add(2, WeightLiteral(b, -2));
+		mb.add(2, WeightLiteral(a, -2));
+
+		newMin = test.buildAndAttach(mb);
+		MinimizeConstraint::SharedDataP shared = newMin->shared();
+
+#define CHECK_LEVEL_WEIGHT(idx, w, l, n) \
+	CHECK(shared->weights.at(idx).weight == w); \
+	CHECK(shared->weights.at(idx).level == l); \
+	CHECK(shared->weights.at(idx).next == n)
+
+		REQUIRE(test.countMinLits() == 3);
+
+		CHECK(shared->lits[0] == WeightLiteral(~b, 0));
+		CHECK_LEVEL_WEIGHT(0, 2, 0, 1);
+		CHECK_LEVEL_WEIGHT(1, -1, 2, 0);
+
+		CHECK(shared->lits[1] == WeightLiteral(~a, 2));
+		CHECK_LEVEL_WEIGHT(2, 2, 0, 1);
+		CHECK_LEVEL_WEIGHT(3, -1, 1, 0);
+
+		CHECK(shared->lits[2] == WeightLiteral(~c, 4));
+		CHECK_LEVEL_WEIGHT(4, 1, 0, 0);
+
+		CHECK(shared->adjust(0) == -5);
+		CHECK(shared->adjust(1) == 1);
+		CHECK(shared->adjust(2) == 1);
+	}
 	SECTION("testInitFromOther") {
 		min.push_back( WeightLiteral(~a, 2) );
 		min.push_back( WeightLiteral(~a, -3));
@@ -510,7 +542,7 @@ TEST_CASE("Model-guided minimize", "[constraint][asp]") {
 		REQUIRE((solver.assume(f) && solver.propagate()));
 		newMin->commitUpperBound(solver);
 		solver.backtrack();
-		// disbale backjumping
+		// disable backjumping
 		solver.setBacktrackLevel(2, Solver::undo_pop_proj_level);
 		REQUIRE(newMin->integrateBound(solver));
 		REQUIRE(solver.decisionLevel() == 2);
@@ -1068,8 +1100,8 @@ TEST_CASE("Core-guided minimize", "[constraint][asp]") {
 		p.opts |= OptParams::usc_disjoint;
 		MinimizeConstraint* m1 = data->attach(s1, p);
 		MinimizeConstraint* m2 = data->attach(s2, p);
-		s1.setEnumerationConstraint(m1);
-		s2.setEnumerationConstraint(m2);
+		SingleOwnerPtr<Constraint, DestroyObject> del1(m1);
+		SingleOwnerPtr<Constraint, DestroyObject> del2(m2);
 		BasicSolve solve(s1);
 		LitVec gp;
 		while (m1->integrate(s1) || m1->handleUnsat(s1, true, gp)) {
