@@ -355,7 +355,7 @@ TEST_CASE("Rule transformation", "[asp][rule]") {
 			<< "1 11 2 0 4 13 \n" // (d,2) :- d, (e,1).
 			<< "1 11 1 0 14 \n"   // (d,2) :- (e,2).
 			<< "1 12 2 0 4 14 \n" // (d,3) :- d, (e,2).
-			<< "1 12 3 0 5 6 7 \n"// (d,3) :- (e,2).
+			<< "1 12 3 0 5 6 7 \n"// (d,3) :- e, f, g.
 
 			<< "1 13 1 0 5 \n"    // (e,1) :- e.
 			<< "1 13 1 0 15 \n"   // (e,1) :- (f,1).
