@@ -5,10 +5,8 @@ using namespace Clingo;
 
 int main(int argc, char const **argv) {
     try {
-        Logger logger = [](Clingo::WarningCode, char const *message) {
-            std::cerr << message << std::endl;
-        };
-        Control ctl{{argv+1, size_t(argc-1)}, logger, 20};
+        Logger logger = [](Clingo::WarningCode, char const *message) { std::cerr << message << std::endl; };
+        Control ctl{{argv + 1, size_t(argc - 1)}, logger, 20};
         ctl.add("base", {}, "a :- not b. b :- not a.");
         ctl.ground({{"base", {}}});
         for (auto &m : ctl.solve()) {
@@ -18,9 +16,7 @@ int main(int argc, char const **argv) {
             }
             std::cout << "\n";
         }
-    }
-    catch (std::exception const &e) {
+    } catch (std::exception const &e) {
         std::cerr << "example failed with: " << e.what() << std::endl;
     }
 }
-
