@@ -24,19 +24,14 @@
 
 #include <clingo/astv2.hh>
 
-namespace Gringo { namespace Input {
+namespace Gringo {
+namespace Input {
 
 namespace {
 
-template <class T>
-T &get(AST &ast, clingo_ast_attribute_e name) {
-    return mpark::get<T>(ast.value(name));
-}
+template <class T> T &get(AST &ast, clingo_ast_attribute_e name) { return mpark::get<T>(ast.value(name)); }
 
-template <class T>
-T const &get(AST const &ast, clingo_ast_attribute_e name) {
-    return mpark::get<T>(ast.value(name));
-}
+template <class T> T const &get(AST const &ast, clingo_ast_attribute_e name) { return mpark::get<T>(ast.value(name)); }
 
 AST *getOpt(AST const &ast, clingo_ast_attribute_e name) {
     if (!ast.hasValue(name)) {
@@ -46,9 +41,8 @@ AST *getOpt(AST const &ast, clingo_ast_attribute_e name) {
 }
 
 struct ASTParser {
-public:
-    ASTParser(Logger &log, INongroundProgramBuilder &prg)
-    : log_(log), prg_(prg) { }
+  public:
+    ASTParser(Logger &log, INongroundProgramBuilder &prg) : log_(log), prg_(prg) {}
 
     // {{{1 statement
 
@@ -61,7 +55,8 @@ public:
             }
             case clingo_ast_type_definition: {
                 return prg_.define(get<Location>(ast, clingo_ast_attribute_location),
-                                   get<String>(ast, clingo_ast_attribute_name), parseTerm(*get<SAST>(ast, clingo_ast_attribute_value)),
+                                   get<String>(ast, clingo_ast_attribute_name),
+                                   parseTerm(*get<SAST>(ast, clingo_ast_attribute_value)),
                                    get<int>(ast, clingo_ast_attribute_is_default) != 0, log_);
             }
             case clingo_ast_type_show_signature: {
@@ -99,12 +94,13 @@ public:
                                      parseTerm(*get<SAST>(ast, clingo_ast_attribute_external_type)));
             }
             case clingo_ast_type_edge: {
-                return prg_.edge(get<Location>(ast, clingo_ast_attribute_location),
-                                 prg_.termvecvec(prg_.termvecvec(),
-                                                 prg_.termvec(prg_.termvec(prg_.termvec(),
-                                                                           parseTerm(*get<SAST>(ast, clingo_ast_attribute_node_u))),
-                                                              parseTerm(*get<SAST>(ast, clingo_ast_attribute_node_v)))),
-                                 parseBodyLiteralVec(get<AST::ASTVec>(ast, clingo_ast_attribute_body)));
+                return prg_.edge(
+                    get<Location>(ast, clingo_ast_attribute_location),
+                    prg_.termvecvec(prg_.termvecvec(),
+                                    prg_.termvec(prg_.termvec(prg_.termvec(),
+                                                              parseTerm(*get<SAST>(ast, clingo_ast_attribute_node_u))),
+                                                 parseTerm(*get<SAST>(ast, clingo_ast_attribute_node_v)))),
+                    parseBodyLiteralVec(get<AST::ASTVec>(ast, clingo_ast_attribute_body)));
             }
             case clingo_ast_type_heuristic: {
                 return prg_.heuristic(get<Location>(ast, clingo_ast_attribute_location),
@@ -132,11 +128,17 @@ public:
                                         get<int>(ast, clingo_ast_attribute_positive) == 0));
             }
             case clingo_ast_type_theory_definition: {
-                return prg_.theorydef(get<Location>(ast, clingo_ast_attribute_location),
-                                      get<String>(ast, clingo_ast_attribute_name),
-                                      parseTheoryAtomDefinitionVec(parseTheoryTermDefinitionVec(get<AST::ASTVec>(ast, clingo_ast_attribute_terms)),
-                                                                   get<AST::ASTVec>(ast, clingo_ast_attribute_atoms)),
-                                      log_);
+                return prg_.theorydef(
+                    get<Location>(ast, clingo_ast_attribute_location), get<String>(ast, clingo_ast_attribute_name),
+                    parseTheoryAtomDefinitionVec(
+                        parseTheoryTermDefinitionVec(get<AST::ASTVec>(ast, clingo_ast_attribute_terms)),
+                        get<AST::ASTVec>(ast, clingo_ast_attribute_atoms)),
+                    log_);
+            }
+            case clingo_ast_type_comment: {
+                return prg_.comment(
+                    get<Location>(ast, clingo_ast_attribute_location), get<String>(ast, clingo_ast_attribute_value),
+                    parseCommentType(get<int>(ast, clingo_ast_attribute_comment_type)) == clingo_comment_type_block);
             }
             default: {
                 throw std::runtime_error("invalid ast: statement expected");
@@ -144,14 +146,13 @@ public:
         }
     }
 
-private:
-    template <class T>
-    T fail_(char const *message) {
-        throw std::runtime_error(message);
-    }
+  private:
+    template <class T> T fail_(char const *message) { throw std::runtime_error(message); }
 
     bool require_(bool cond, char const *message) {
-        if (!cond) { fail_<void>(message); }
+        if (!cond) {
+            fail_<void>(message);
+        }
         return false;
     }
 
@@ -161,7 +162,8 @@ private:
         auto uid = prg_.idvec();
         for (auto const &ast : asts) {
             require_(ast->type() == clingo_ast_type_id, "invalid ast: id required");
-            prg_.idvec(uid, get<Location>(*ast, clingo_ast_attribute_location), get<String>(*ast, clingo_ast_attribute_name));
+            prg_.idvec(uid, get<Location>(*ast, clingo_ast_attribute_location),
+                       get<String>(*ast, clingo_ast_attribute_name));
         }
         return uid;
     }
@@ -245,18 +247,17 @@ private:
                                  parseTerm(*get<SAST>(ast, clingo_ast_attribute_right)));
             }
             case clingo_ast_type_function: {
-                auto external = ast.hasValue(clingo_ast_attribute_external) && get<int>(ast, clingo_ast_attribute_external) != 0;
+                auto external =
+                    ast.hasValue(clingo_ast_attribute_external) && get<int>(ast, clingo_ast_attribute_external) != 0;
                 auto name = get<String>(ast, clingo_ast_attribute_name);
                 require_(!name.empty() || !external, "invalid ast: external functions must have a name");
                 return !name.empty()
-                    ? prg_.term(get<Location>(ast, clingo_ast_attribute_location),
-                                name,
-                                prg_.termvecvec(prg_.termvecvec(),
-                                                parseTermVec(get<AST::ASTVec>(ast, clingo_ast_attribute_arguments))),
-                                external)
-                    : prg_.term(get<Location>(ast, clingo_ast_attribute_location),
-                                parseTermVec(get<AST::ASTVec>(ast, clingo_ast_attribute_arguments)),
-                                true);
+                           ? prg_.term(get<Location>(ast, clingo_ast_attribute_location), name,
+                                       prg_.termvecvec(prg_.termvecvec(), parseTermVec(get<AST::ASTVec>(
+                                                                              ast, clingo_ast_attribute_arguments))),
+                                       external)
+                           : prg_.term(get<Location>(ast, clingo_ast_attribute_location),
+                                       parseTermVec(get<AST::ASTVec>(ast, clingo_ast_attribute_arguments)), true);
             }
             case clingo_ast_type_pool: {
                 return prg_.pool(get<Location>(ast, clingo_ast_attribute_location),
@@ -278,29 +279,33 @@ private:
 
     TheoryTermUid parseTheoryTerm(AST const &ast) {
         switch (ast.type()) {
-            case clingo_ast_type_symbolic_term : {
-                return prg_.theorytermvalue(get<Location>(ast, clingo_ast_attribute_location), get<Symbol>(ast, clingo_ast_attribute_symbol));
+            case clingo_ast_type_symbolic_term: {
+                return prg_.theorytermvalue(get<Location>(ast, clingo_ast_attribute_location),
+                                            get<Symbol>(ast, clingo_ast_attribute_symbol));
             }
             case clingo_ast_type_variable: {
-                return prg_.theorytermvar(get<Location>(ast, clingo_ast_attribute_location), get<String>(ast, clingo_ast_attribute_name));
+                return prg_.theorytermvar(get<Location>(ast, clingo_ast_attribute_location),
+                                          get<String>(ast, clingo_ast_attribute_name));
             }
             case clingo_ast_type_theory_sequence: {
                 switch (get<int>(ast, clingo_ast_attribute_sequence_type)) {
                     case clingo_ast_theory_sequence_type_tuple: {
-                        return prg_.theorytermtuple(get<Location>(ast, clingo_ast_attribute_location),
-                                                    parseTheoryOptermVec(get<AST::ASTVec>(ast, clingo_ast_attribute_terms)));
+                        return prg_.theorytermtuple(
+                            get<Location>(ast, clingo_ast_attribute_location),
+                            parseTheoryOptermVec(get<AST::ASTVec>(ast, clingo_ast_attribute_terms)));
                     }
                     case clingo_ast_theory_sequence_type_list: {
-                        return prg_.theoryoptermlist(get<Location>(ast, clingo_ast_attribute_location),
-                                                     parseTheoryOptermVec(get<AST::ASTVec>(ast, clingo_ast_attribute_terms)));
+                        return prg_.theoryoptermlist(
+                            get<Location>(ast, clingo_ast_attribute_location),
+                            parseTheoryOptermVec(get<AST::ASTVec>(ast, clingo_ast_attribute_terms)));
                     }
                     case clingo_ast_theory_sequence_type_set: {
-                        return prg_.theorytermset(get<Location>(ast, clingo_ast_attribute_location),
-                                                  parseTheoryOptermVec(get<AST::ASTVec>(ast, clingo_ast_attribute_terms)));
+                        return prg_.theorytermset(
+                            get<Location>(ast, clingo_ast_attribute_location),
+                            parseTheoryOptermVec(get<AST::ASTVec>(ast, clingo_ast_attribute_terms)));
                     }
                     default: {
                         throw std::runtime_error("invalid ast: invalid theory sequence type");
-
                     }
                 }
             }
@@ -310,8 +315,9 @@ private:
                                           parseTheoryOptermVec(get<AST::ASTVec>(ast, clingo_ast_attribute_arguments)));
             }
             case clingo_ast_type_theory_unparsed_term: {
-                return prg_.theorytermopterm(get<Location>(ast, clingo_ast_attribute_location),
-                                             parseTheoryUnparsedTermElements(get<AST::ASTVec>(ast, clingo_ast_attribute_elements)));
+                return prg_.theorytermopterm(
+                    get<Location>(ast, clingo_ast_attribute_location),
+                    parseTheoryUnparsedTermElements(get<AST::ASTVec>(ast, clingo_ast_attribute_elements)));
             }
             default: {
                 throw std::runtime_error("invalid ast: theory term expected");
@@ -319,7 +325,6 @@ private:
         }
     }
 
-
     TheoryOptermVecUid parseTheoryOptermVec(AST::ASTVec const &asts) {
         auto uid = prg_.theoryopterms();
         for (auto const &ast : asts) {
@@ -351,9 +356,9 @@ private:
                                      parseTheoryTerm(*get<SAST>(**it, clingo_ast_attribute_term)));
         for (++it; it != ie; ++it) {
             auto const &operators = get<AST::StrVec>(**it, clingo_ast_attribute_operators);
-            require_(!operators.empty(), "invalid ast: at least one operator necessary on right-hand-side of unparsed theory term");
-            uid = prg_.theoryopterm(uid,
-                                    parseTheoryOpVec(operators),
+            require_(!operators.empty(),
+                     "invalid ast: at least one operator necessary on right-hand-side of unparsed theory term");
+            uid = prg_.theoryopterm(uid, parseTheoryOpVec(operators),
                                     parseTheoryTerm(*get<SAST>(**it, clingo_ast_attribute_term)));
         }
         return uid;
@@ -414,15 +419,13 @@ private:
             throw std::runtime_error("invalid ast: a comparision must have at least one guard");
         }
         auto lhs = get<SAST>(*vec.front(), clingo_ast_attribute_term);
-        auto ret = prg_.rellitvec(get<Location>(*lhs, clingo_ast_attribute_location),
-                                  parseRelation(get<int>(*vec.front(), clingo_ast_attribute_comparison)),
-                                  parseTerm(*lhs));
+        auto ret =
+            prg_.rellitvec(get<Location>(*lhs, clingo_ast_attribute_location),
+                           parseRelation(get<int>(*vec.front(), clingo_ast_attribute_comparison)), parseTerm(*lhs));
         for (auto it = vec.begin() + 1, ie = vec.end(); it != ie; ++it) {
             auto rhs = get<SAST>(**it, clingo_ast_attribute_term);
-            ret = prg_.rellitvec(get<Location>(*rhs, clingo_ast_attribute_location),
-                                 ret,
-                                 parseRelation(get<int>(**it, clingo_ast_attribute_comparison)),
-                                 parseTerm(*rhs));
+            ret = prg_.rellitvec(get<Location>(*rhs, clingo_ast_attribute_location), ret,
+                                 parseRelation(get<int>(**it, clingo_ast_attribute_comparison)), parseTerm(*rhs));
         }
         return ret;
     }
@@ -437,18 +440,13 @@ private:
                 switch (atom.type()) {
                     case clingo_ast_type_boolean_constant: {
                         int cmp = sign == NAF::NOT ? 1 : 0;
-                        return prg_.boollit(loc,
-                                            get<int>(atom, clingo_ast_attribute_value) != cmp);
+                        return prg_.boollit(loc, get<int>(atom, clingo_ast_attribute_value) != cmp);
                     }
                     case clingo_ast_type_symbolic_atom: {
-                        return prg_.predlit(loc,
-                                            sign,
-                                            parseAtom(*get<SAST>(ast, clingo_ast_attribute_atom)));
+                        return prg_.predlit(loc, sign, parseAtom(*get<SAST>(ast, clingo_ast_attribute_atom)));
                     }
                     case clingo_ast_type_comparison: {
-                        return prg_.rellit(loc,
-                                           sign,
-                                           parseTerm(*get<SAST>(atom, clingo_ast_attribute_term)),
+                        return prg_.rellit(loc, sign, parseTerm(*get<SAST>(atom, clingo_ast_attribute_term)),
                                            parseRightGuards(get<AST::ASTVec>(atom, clingo_ast_attribute_guards)));
                     }
                     default: {
@@ -499,14 +497,12 @@ private:
         auto ret = prg_.boundvec();
         auto const *right = getOpt(ast, clingo_ast_attribute_right_guard);
         if (right != nullptr) {
-            ret = prg_.boundvec(ret,
-                                parseRelation(get<int>(*right, clingo_ast_attribute_comparison)),
+            ret = prg_.boundvec(ret, parseRelation(get<int>(*right, clingo_ast_attribute_comparison)),
                                 parseTerm(*get<SAST>(*right, clingo_ast_attribute_term)));
         }
         auto const *left = getOpt(ast, clingo_ast_attribute_left_guard);
         if (left != nullptr) {
-            ret = prg_.boundvec(ret,
-                                inv(parseRelation(get<int>(*left, clingo_ast_attribute_comparison))),
+            ret = prg_.boundvec(ret, inv(parseRelation(get<int>(*left, clingo_ast_attribute_comparison))),
                                 parseTerm(*get<SAST>(*left, clingo_ast_attribute_term)));
         }
         return ret;
@@ -515,8 +511,7 @@ private:
     CondLitVecUid parseCondLitVec(AST::ASTVec const &asts) {
         auto uid = prg_.condlitvec();
         for (auto const &ast : asts) {
-            uid = prg_.condlitvec(uid,
-                                  parseLiteral(*get<SAST>(*ast, clingo_ast_attribute_literal)),
+            uid = prg_.condlitvec(uid, parseLiteral(*get<SAST>(*ast, clingo_ast_attribute_literal)),
                                   parseLiteralVec(get<AST::ASTVec>(*ast, clingo_ast_attribute_condition)));
         }
         return uid;
@@ -525,11 +520,11 @@ private:
     HdAggrElemVecUid parseHdAggrElemVec(AST::ASTVec const &asts) {
         auto uid = prg_.headaggrelemvec();
         for (auto const &ast : asts) {
-            require_(ast->type() == clingo_ast_type_head_aggregate_element, "invalid ast: head aggregate element expected");
+            require_(ast->type() == clingo_ast_type_head_aggregate_element,
+                     "invalid ast: head aggregate element expected");
             auto const &clit = get<SAST>(*ast, clingo_ast_attribute_condition);
             require_(clit->type() == clingo_ast_type_conditional_literal, "invalid ast: conditional literal expected");
-            uid = prg_.headaggrelemvec(uid,
-                                       parseTermVec(get<AST::ASTVec>(*ast, clingo_ast_attribute_terms)),
+            uid = prg_.headaggrelemvec(uid, parseTermVec(get<AST::ASTVec>(*ast, clingo_ast_attribute_terms)),
                                        parseLiteral(*get<SAST>(*clit, clingo_ast_attribute_literal)),
                                        parseLiteralVec(get<AST::ASTVec>(*clit, clingo_ast_attribute_condition)));
         }
@@ -539,9 +534,9 @@ private:
     BdAggrElemVecUid parseBdAggrElemVec(AST::ASTVec const &asts) {
         auto uid = prg_.bodyaggrelemvec();
         for (auto const &ast : asts) {
-            require_(ast->type() == clingo_ast_type_body_aggregate_element, "invalid ast: body aggregate element expected");
-            uid = prg_.bodyaggrelemvec(uid,
-                                       parseTermVec(get<AST::ASTVec>(*ast, clingo_ast_attribute_terms)),
+            require_(ast->type() == clingo_ast_type_body_aggregate_element,
+                     "invalid ast: body aggregate element expected");
+            uid = prg_.bodyaggrelemvec(uid, parseTermVec(get<AST::ASTVec>(*ast, clingo_ast_attribute_terms)),
                                        parseLiteralVec(get<AST::ASTVec>(*ast, clingo_ast_attribute_condition)));
         }
         return uid;
@@ -550,8 +545,7 @@ private:
     TheoryElemVecUid parseTheoryElemVec(AST::ASTVec const &asts) {
         auto uid = prg_.theoryelems();
         for (auto const &ast : asts) {
-            uid = prg_.theoryelems(uid,
-                                   parseTheoryOptermVec(get<AST::ASTVec>(*ast, clingo_ast_attribute_terms)),
+            uid = prg_.theoryelems(uid, parseTheoryOptermVec(get<AST::ASTVec>(*ast, clingo_ast_attribute_terms)),
                                    parseLiteralVec(get<AST::ASTVec>(*ast, clingo_ast_attribute_condition)));
         }
         return uid;
@@ -564,13 +558,9 @@ private:
         auto term = parseTerm(*get<SAST>(ast, clingo_ast_attribute_term));
         auto elements = parseTheoryElemVec(get<AST::ASTVec>(ast, clingo_ast_attribute_elements));
         return guard != nullptr
-            ? prg_.theoryatom(term,
-                              elements,
-                              get<String>(*guard, clingo_ast_attribute_operator_name),
-                              loc,
-                              parseTheoryOpterm(*get<SAST>(*guard, clingo_ast_attribute_term)))
-            : prg_.theoryatom(term, elements);
-
+                   ? prg_.theoryatom(term, elements, get<String>(*guard, clingo_ast_attribute_operator_name), loc,
+                                     parseTheoryOpterm(*get<SAST>(*guard, clingo_ast_attribute_term)))
+                   : prg_.theoryatom(term, elements);
     }
 
     // {{{1 heads
@@ -585,8 +575,7 @@ private:
                                         parseCondLitVec(get<AST::ASTVec>(ast, clingo_ast_attribute_elements)));
             }
             case clingo_ast_type_aggregate: {
-                return prg_.headaggr(get<Location>(ast, clingo_ast_attribute_location),
-                                     AggregateFunction::COUNT,
+                return prg_.headaggr(get<Location>(ast, clingo_ast_attribute_location), AggregateFunction::COUNT,
                                      parseBounds(ast),
                                      parseCondLitVec(get<AST::ASTVec>(ast, clingo_ast_attribute_elements)));
             }
@@ -618,16 +607,15 @@ private:
                     auto const &atom = *get<SAST>(*lit, clingo_ast_attribute_atom);
                     switch (atom.type()) {
                         case clingo_ast_type_aggregate: {
-                            uid = prg_.bodyaggr(uid, loc, sign, AggregateFunction::COUNT,
-                                                parseBounds(atom),
+                            uid = prg_.bodyaggr(uid, loc, sign, AggregateFunction::COUNT, parseBounds(atom),
                                                 parseCondLitVec(get<AST::ASTVec>(atom, clingo_ast_attribute_elements)));
                             break;
                         }
                         case clingo_ast_type_body_aggregate: {
-                            uid = prg_.bodyaggr(uid, loc, sign,
-                                                parseAggregateFunction(get<int>(atom, clingo_ast_attribute_function)),
-                                                parseBounds(atom),
-                                                parseBdAggrElemVec(get<AST::ASTVec>(atom, clingo_ast_attribute_elements)));
+                            uid = prg_.bodyaggr(
+                                uid, loc, sign, parseAggregateFunction(get<int>(atom, clingo_ast_attribute_function)),
+                                parseBounds(atom),
+                                parseBdAggrElemVec(get<AST::ASTVec>(atom, clingo_ast_attribute_elements)));
                             break;
                         }
                         case clingo_ast_type_theory_atom: {
@@ -642,8 +630,7 @@ private:
                     break;
                 }
                 case clingo_ast_type_conditional_literal: {
-                    uid = prg_.conjunction(uid,
-                                           get<Location>(*lit, clingo_ast_attribute_location),
+                    uid = prg_.conjunction(uid, get<Location>(*lit, clingo_ast_attribute_location),
                                            parseLiteral(*get<SAST>(*lit, clingo_ast_attribute_literal)),
                                            parseLiteralVec(get<AST::ASTVec>(*lit, clingo_ast_attribute_condition)));
                     break;
@@ -676,7 +663,8 @@ private:
     }
 
     TheoryOpDefUid parseTheoryOpDef(AST const &ast) {
-        require_(ast.type() == clingo_ast_type_theory_operator_definition, "invalid ast: theory operator definition expected");
+        require_(ast.type() == clingo_ast_type_theory_operator_definition,
+                 "invalid ast: theory operator definition expected");
         return prg_.theoryopdef(get<Location>(ast, clingo_ast_attribute_location),
                                 get<String>(ast, clingo_ast_attribute_name),
                                 get<int>(ast, clingo_ast_attribute_priority),
@@ -720,10 +708,10 @@ private:
         auto term = get<String>(ast, clingo_ast_attribute_term);
         auto type = parseTheoryAtomType(get<int>(ast, clingo_ast_attribute_atom_type));
         return guard != nullptr
-            ? prg_.theoryatomdef(loc, name, arity, term, type,
-                                 parseTheoryOpVec(get<AST::StrVec>(*guard, clingo_ast_attribute_operators)),
-                                 get<String>(*guard, clingo_ast_attribute_term))
-            : prg_.theoryatomdef(loc, name, arity, term, type);
+                   ? prg_.theoryatomdef(loc, name, arity, term, type,
+                                        parseTheoryOpVec(get<AST::StrVec>(*guard, clingo_ast_attribute_operators)),
+                                        get<String>(*guard, clingo_ast_attribute_term))
+                   : prg_.theoryatomdef(loc, name, arity, term, type);
     }
 
     TheoryDefVecUid parseTheoryAtomDefinitionVec(TheoryDefVecUid uid, AST::ASTVec const &asts) {
@@ -736,8 +724,7 @@ private:
     TheoryTermDefUid parseTheoryTermDefinition(AST const &ast) {
         return prg_.theorytermdef(get<Location>(ast, clingo_ast_attribute_location),
                                   get<String>(ast, clingo_ast_attribute_name),
-                                  parseTheoryOpDefVec(get<AST::ASTVec>(ast, clingo_ast_attribute_operators)),
-                                  log_);
+                                  parseTheoryOpDefVec(get<AST::ASTVec>(ast, clingo_ast_attribute_operators)), log_);
     }
 
     TheoryDefVecUid parseTheoryTermDefinitionVec(AST::ASTVec const &asts) {
@@ -748,6 +735,21 @@ private:
         return uid;
     }
 
+    // {{{1 comments
+
+    static clingo_comment_type_t parseCommentType(int num) {
+        switch (num) {
+            case clingo_comment_type_line: {
+                return clingo_comment_type_line;
+            }
+            case clingo_comment_type_block: {
+                return clingo_comment_type_block;
+            }
+            default: {
+                throw std::runtime_error("invalid ast: invalid comment type");
+            }
+        }
+    }
     // 1}}}
 
     Logger &log_;
@@ -756,8 +758,7 @@ private:
 
 } // namespace
 
-void parse(INongroundProgramBuilder &prg, Logger &log, AST const &ast) {
-    ASTParser{log, prg}.parseStatement(ast);
-}
+void parse(INongroundProgramBuilder &prg, Logger &log, AST const &ast) { ASTParser{log, prg}.parseStatement(ast); }
 
-} } // namespace Input Gringo
+} // namespace Input
+} // namespace Gringo
