@@ -28,7 +28,6 @@
 namespace Gringo {
 
 bool Scripts::callable(String name) {
-    if (context_ && context_->callable(name)) { return true; }
     for (auto &&script : scripts_) {
         if (std::get<1>(script) && std::get<2>(script)->callable(name)) {
             return true;
@@ -47,21 +46,20 @@ void Scripts::main(Control &ctl) {
 }
 
 SymVec Scripts::call(Location const &loc, String name, SymSpan args, Logger &log) {
-    if (context_ && context_->callable(name)) { return context_->call(loc, name, args, log); }
     for (auto &&script : scripts_) {
         if (std::get<1>(script) && std::get<2>(script)->callable(name)) {
             return std::get<2>(script)->call(loc, name, args, log);
         }
     }
-    GRINGO_REPORT(log, Warnings::OperationUndefined)
-        << loc << ": info: operation undefined:\n"
-        << "  function '" << name << "' not found\n"
-        ;
+    GRINGO_REPORT(log, Warnings::OperationUndefined) << loc << ": info: operation undefined:\n"
+                                                     << "  function '" << name << "' not found\n";
     return {};
 }
 
 void Scripts::registerScript(String type, UScript script) {
-    if (script) { scripts_.emplace_back(type, false, std::move(script)); }
+    if (script) {
+        scripts_.emplace_back(type, false, std::move(script));
+    }
 }
 
 void Scripts::exec(String type, Location loc, String code) {
