@@ -23,27 +23,24 @@
 // }}}
 
 #include "gringo/input/programbuilder.hh"
-#include "gringo/input/literals.hh"
 #include "gringo/input/aggregates.hh"
+#include "gringo/input/literals.hh"
 #include "gringo/input/program.hh"
 #include "gringo/input/theory.hh"
 #include "gringo/output/output.hh"
 
 #ifdef _MSC_VER
-#pragma warning (disable : 4503) // decorated name length exceeded
+#pragma warning(disable : 4503) // decorated name length exceeded
 #endif
 
-namespace Gringo { namespace Input {
+namespace Gringo {
+namespace Input {
 
 // {{{1 definition of NongroundProgramBuilder
 
-NongroundProgramBuilder::NongroundProgramBuilder(Context &context, Program &prg, OutputPredicates &output_preds, Defines &defs, bool rewriteMinimize)
-: context_(context)
-, prg_(prg)
-, output_preds_(output_preds)
-, defs_(defs)
-, rewriteMinimize_(rewriteMinimize)
-{ }
+NongroundProgramBuilder::NongroundProgramBuilder(Context &context, Program &prg, OutputPredicates &output_preds,
+                                                 Defines &defs, bool rewriteMinimize)
+    : context_(context), prg_(prg), output_preds_(output_preds), defs_(defs), rewriteMinimize_(rewriteMinimize) {}
 
 // {{{2 terms
 
@@ -115,7 +112,8 @@ TermUid NongroundProgramBuilder::term(Location const &loc, String name, TermVecV
 
 TermUid NongroundProgramBuilder::term(Location const &loc, TermVecUid args, bool forceTuple) {
     UTermVec a(termvecs_.erase(args));
-    UTerm ret(!forceTuple && a.size() == 1 ? std::move(a.front()) : make_locatable<FunctionTerm>(loc, "", std::move(a)));
+    UTerm ret(!forceTuple && a.size() == 1 ? std::move(a.front())
+                                           : make_locatable<FunctionTerm>(loc, "", std::move(a)));
     return terms_.insert(std::move(ret));
 }
 
@@ -125,9 +123,7 @@ TermUid NongroundProgramBuilder::pool(Location const &loc, TermVecUid args) {
 
 // {{{2 id vectors
 
-IdVecUid NongroundProgramBuilder::idvec() {
-    return idvecs_.emplace();
-}
+IdVecUid NongroundProgramBuilder::idvec() { return idvecs_.emplace(); }
 IdVecUid NongroundProgramBuilder::idvec(IdVecUid uid, Location const &loc, String id) {
     idvecs_[uid].emplace_back(loc, id);
     return uid;
@@ -135,9 +131,7 @@ IdVecUid NongroundProgramBuilder::idvec(IdVecUid uid, Location const &loc, Strin
 
 // {{{2 termvecs
 
-TermVecUid NongroundProgramBuilder::termvec() {
-    return termvecs_.emplace();
-}
+TermVecUid NongroundProgramBuilder::termvec() { return termvecs_.emplace(); }
 
 TermVecUid NongroundProgramBuilder::termvec(TermVecUid uid, TermUid term) {
     termvecs_[uid].emplace_back(terms_.erase(term));
@@ -146,9 +140,7 @@ TermVecUid NongroundProgramBuilder::termvec(TermVecUid uid, TermUid term) {
 
 // {{{2 termvecvecs
 
-TermVecVecUid NongroundProgramBuilder::termvecvec() {
-    return termvecvecs_.emplace();
-}
+TermVecVecUid NongroundProgramBuilder::termvecvec() { return termvecvecs_.emplace(); }
 
 TermVecVecUid NongroundProgramBuilder::termvecvec(TermVecVecUid uid, TermVecUid termvecUid) {
     termvecvecs_[uid].emplace_back(termvecs_.erase(termvecUid));
@@ -158,7 +150,8 @@ TermVecVecUid NongroundProgramBuilder::termvecvec(TermVecVecUid uid, TermVecUid
 // {{{2 literals
 
 LitUid NongroundProgramBuilder::boollit(Location const &loc, bool type) {
-    return rellit(loc, NAF::POS, term(loc, Symbol::createNum(0)), rellitvec(loc, type ? Relation::EQ : Relation::NEQ, term(loc, Symbol::createNum(0))));
+    return rellit(loc, NAF::POS, term(loc, Symbol::createNum(0)),
+                  rellitvec(loc, type ? Relation::EQ : Relation::NEQ, term(loc, Symbol::createNum(0))));
 }
 
 LitUid NongroundProgramBuilder::predlit(Location const &loc, NAF naf, TermUid term) {
@@ -171,20 +164,20 @@ RelLitVecUid NongroundProgramBuilder::rellitvec(Location const &loc, Relation re
     return uid;
 }
 
-RelLitVecUid NongroundProgramBuilder::rellitvec(Location const &loc, RelLitVecUid vecUidLeft, Relation rel, TermUid termUidRight) {
+RelLitVecUid NongroundProgramBuilder::rellitvec(Location const &loc, RelLitVecUid vecUidLeft, Relation rel,
+                                                TermUid termUidRight) {
     rellitvecs_[vecUidLeft].emplace_back(rel, terms_.erase(termUidRight));
     return vecUidLeft;
 }
 
 LitUid NongroundProgramBuilder::rellit(Location const &loc, NAF naf, TermUid termUidLeft, RelLitVecUid vecUidRight) {
-    return lits_.insert(make_locatable<RelationLiteral>(loc, naf, terms_.erase(termUidLeft), rellitvecs_.erase(vecUidRight)));
+    return lits_.insert(
+        make_locatable<RelationLiteral>(loc, naf, terms_.erase(termUidLeft), rellitvecs_.erase(vecUidRight)));
 }
 
 // {{{2 literal vectors
 
-LitVecUid NongroundProgramBuilder::litvec() {
-    return litvecs_.emplace();
-}
+LitVecUid NongroundProgramBuilder::litvec() { return litvecs_.emplace(); }
 
 LitVecUid NongroundProgramBuilder::litvec(LitVecUid uid, LitUid literalUid) {
     litvecs_[uid].emplace_back(lits_.erase(literalUid));
@@ -193,18 +186,14 @@ LitVecUid NongroundProgramBuilder::litvec(LitVecUid uid, LitUid literalUid) {
 
 // {{{2 body aggregate element vectors
 
-BdAggrElemVecUid NongroundProgramBuilder::bodyaggrelemvec() {
-    return bodyaggrelemvecs_.emplace();
-}
+BdAggrElemVecUid NongroundProgramBuilder::bodyaggrelemvec() { return bodyaggrelemvecs_.emplace(); }
 
 BdAggrElemVecUid NongroundProgramBuilder::bodyaggrelemvec(BdAggrElemVecUid uid, TermVecUid termvec, LitVecUid litvec) {
     bodyaggrelemvecs_[uid].emplace_back(termvecs_.erase(termvec), litvecs_.erase(litvec));
     return uid;
 }
 
-CondLitVecUid NongroundProgramBuilder::condlitvec() {
-    return condlitvecs_.emplace();
-}
+CondLitVecUid NongroundProgramBuilder::condlitvec() { return condlitvecs_.emplace(); }
 
 CondLitVecUid NongroundProgramBuilder::condlitvec(CondLitVecUid uid, LitUid lit, LitVecUid litvec) {
     condlitvecs_[uid].emplace_back(lits_.erase(lit), litvecs_.erase(litvec));
@@ -213,20 +202,17 @@ CondLitVecUid NongroundProgramBuilder::condlitvec(CondLitVecUid uid, LitUid lit,
 
 // {{{2 head aggregate element vectors
 
-HdAggrElemVecUid NongroundProgramBuilder::headaggrelemvec() {
-    return headaggrelemvecs_.emplace();
-}
+HdAggrElemVecUid NongroundProgramBuilder::headaggrelemvec() { return headaggrelemvecs_.emplace(); }
 
-HdAggrElemVecUid NongroundProgramBuilder::headaggrelemvec(HdAggrElemVecUid uid, TermVecUid termvec, LitUid lit, LitVecUid litvec) {
+HdAggrElemVecUid NongroundProgramBuilder::headaggrelemvec(HdAggrElemVecUid uid, TermVecUid termvec, LitUid lit,
+                                                          LitVecUid litvec) {
     headaggrelemvecs_[uid].emplace_back(termvecs_.erase(termvec), lits_.erase(lit), litvecs_.erase(litvec));
     return uid;
 }
 
 // {{{2 bounds
 
-BoundVecUid NongroundProgramBuilder::boundvec() {
-    return bounds_.emplace();
-}
+BoundVecUid NongroundProgramBuilder::boundvec() { return bounds_.emplace(); }
 
 BoundVecUid NongroundProgramBuilder::boundvec(BoundVecUid uid, Relation rel, TermUid term) {
     bounds_[uid].emplace_back(rel, terms_.erase(term));
@@ -235,22 +221,24 @@ BoundVecUid NongroundProgramBuilder::boundvec(BoundVecUid uid, Relation rel, Ter
 
 // {{{2 rule bodies
 
-BdLitVecUid NongroundProgramBuilder::body() {
-    return bodies_.emplace();
-}
+BdLitVecUid NongroundProgramBuilder::body() { return bodies_.emplace(); }
 
 BdLitVecUid NongroundProgramBuilder::bodylit(BdLitVecUid body, LitUid bodylit) {
     bodies_[body].push_back(gringo_make_unique<SimpleBodyLiteral>(lits_.erase(bodylit)));
     return body;
 }
 
-BdLitVecUid NongroundProgramBuilder::bodyaggr(BdLitVecUid body, Location const &loc, NAF naf, AggregateFunction fun, BoundVecUid bounds, BdAggrElemVecUid bodyaggrelemvec) {
-    bodies_[body].push_back(make_locatable<TupleBodyAggregate>(loc, naf, fun, bounds_.erase(bounds), bodyaggrelemvecs_.erase(bodyaggrelemvec)));
+BdLitVecUid NongroundProgramBuilder::bodyaggr(BdLitVecUid body, Location const &loc, NAF naf, AggregateFunction fun,
+                                              BoundVecUid bounds, BdAggrElemVecUid bodyaggrelemvec) {
+    bodies_[body].push_back(make_locatable<TupleBodyAggregate>(loc, naf, fun, bounds_.erase(bounds),
+                                                               bodyaggrelemvecs_.erase(bodyaggrelemvec)));
     return body;
 }
 
-BdLitVecUid NongroundProgramBuilder::bodyaggr(BdLitVecUid body, Location const &loc, NAF naf, AggregateFunction fun, BoundVecUid bounds, CondLitVecUid condlitvecuid) {
-    bodies_[body].push_back(make_locatable<LitBodyAggregate>(loc, naf, fun, bounds_.erase(bounds), condlitvecs_.erase(condlitvecuid)));
+BdLitVecUid NongroundProgramBuilder::bodyaggr(BdLitVecUid body, Location const &loc, NAF naf, AggregateFunction fun,
+                                              BoundVecUid bounds, CondLitVecUid condlitvecuid) {
+    bodies_[body].push_back(
+        make_locatable<LitBodyAggregate>(loc, naf, fun, bounds_.erase(bounds), condlitvecs_.erase(condlitvecuid)));
     return body;
 }
 
@@ -265,12 +253,16 @@ HdLitUid NongroundProgramBuilder::headlit(LitUid lit) {
     return heads_.insert(gringo_make_unique<SimpleHeadLiteral>(lits_.erase(lit)));
 }
 
-HdLitUid NongroundProgramBuilder::headaggr(Location const &loc, AggregateFunction fun, BoundVecUid bounds, HdAggrElemVecUid headaggrelemvec) {
-    return heads_.insert(make_locatable<TupleHeadAggregate>(loc, fun, bounds_.erase(bounds), headaggrelemvecs_.erase(headaggrelemvec)));
+HdLitUid NongroundProgramBuilder::headaggr(Location const &loc, AggregateFunction fun, BoundVecUid bounds,
+                                           HdAggrElemVecUid headaggrelemvec) {
+    return heads_.insert(
+        make_locatable<TupleHeadAggregate>(loc, fun, bounds_.erase(bounds), headaggrelemvecs_.erase(headaggrelemvec)));
 }
 
-HdLitUid NongroundProgramBuilder::headaggr(Location const &loc, AggregateFunction fun, BoundVecUid bounds, CondLitVecUid condlitvec) {
-    return heads_.insert(make_locatable<LitHeadAggregate>(loc, fun, bounds_.erase(bounds), condlitvecs_.erase(condlitvec)));
+HdLitUid NongroundProgramBuilder::headaggr(Location const &loc, AggregateFunction fun, BoundVecUid bounds,
+                                           CondLitVecUid condlitvec) {
+    return heads_.insert(
+        make_locatable<LitHeadAggregate>(loc, fun, bounds_.erase(bounds), condlitvecs_.erase(condlitvec)));
 }
 
 HdLitUid NongroundProgramBuilder::disjunction(Location const &loc, CondLitVecUid condlitvec) {
@@ -279,9 +271,7 @@ HdLitUid NongroundProgramBuilder::disjunction(Location const &loc, CondLitVecUid
 
 // {{{2 statements
 
-void NongroundProgramBuilder::rule(Location const &loc, HdLitUid head) {
-    rule(loc, head, body());
-}
+void NongroundProgramBuilder::rule(Location const &loc, HdLitUid head) { rule(loc, head, body()); }
 
 void NongroundProgramBuilder::rule(Location const &loc, HdLitUid head, BdLitVecUid body) {
     prg_.add(make_locatable<Statement>(loc, heads_.erase(head), bodies_.erase(body)));
@@ -291,22 +281,24 @@ void NongroundProgramBuilder::define(Location const &loc, String name, TermUid v
     defs_.add(loc, name, terms_.erase(value), defaultDef, log);
 }
 
-void NongroundProgramBuilder::optimize(Location const &loc, TermUid weight, TermUid priority, TermVecUid cond, BdLitVecUid body) {
+void NongroundProgramBuilder::optimize(Location const &loc, TermUid weight, TermUid priority, TermVecUid cond,
+                                       BdLitVecUid body) {
     if (rewriteMinimize_) {
         auto argsUid = termvec(termvec(termvec(), priority), weight);
         termvec(argsUid, term(loc, cond, true));
         auto predUid = predlit(loc, NAF::POS, term(loc, "_criteria", termvecvec(termvecvec(), argsUid), false));
         rule(loc, headlit(predUid), body);
         output_preds_.add(loc, Sig("_criteria", 3, false), true);
-    }
-    else {
-        prg_.add(make_locatable<Statement>(loc, make_locatable<MinimizeHeadLiteral>(loc, terms_.erase(weight), terms_.erase(priority), termvecs_.erase(cond)), bodies_.erase(body)));
+    } else {
+        prg_.add(make_locatable<Statement>(loc,
+                                           make_locatable<MinimizeHeadLiteral>(loc, terms_.erase(weight),
+                                                                               terms_.erase(priority),
+                                                                               termvecs_.erase(cond)),
+                                           bodies_.erase(body)));
     }
 }
 
-void NongroundProgramBuilder::showsig(Location const &loc, Sig sig) {
-    output_preds_.add(loc, sig, false);
-}
+void NongroundProgramBuilder::showsig(Location const &loc, Sig sig) { output_preds_.add(loc, sig, false); }
 
 void NongroundProgramBuilder::defined(Location const &loc, Sig sig) {
     static_cast<void>(loc);
@@ -314,42 +306,41 @@ void NongroundProgramBuilder::defined(Location const &loc, Sig sig) {
 }
 
 void NongroundProgramBuilder::show(Location const &loc, TermUid t, BdLitVecUid body) {
-    prg_.add(make_locatable<Statement>(loc, make_locatable<ShowHeadLiteral>(loc, terms_.erase(t)), bodies_.erase(body)));
+    prg_.add(
+        make_locatable<Statement>(loc, make_locatable<ShowHeadLiteral>(loc, terms_.erase(t)), bodies_.erase(body)));
 }
 
-void NongroundProgramBuilder::script(Location const &loc, String type, String code) {
-    context_.exec(type, loc, code);
-}
+void NongroundProgramBuilder::script(Location const &loc, String type, String code) { context_.exec(type, loc, code); }
 
 void NongroundProgramBuilder::block(Location const &loc, String name, IdVecUid args) {
     prg_.begin(loc, name, idvecs_.erase(args));
 }
 
 void NongroundProgramBuilder::external(Location const &loc, TermUid head, BdLitVecUid body, TermUid type) {
-    prg_.add(make_locatable<Statement>(loc, make_locatable<ExternalHeadAtom>(loc, terms_.erase(head), terms_.erase(type)), bodies_.erase(body)));
+    prg_.add(make_locatable<Statement>(
+        loc, make_locatable<ExternalHeadAtom>(loc, terms_.erase(head), terms_.erase(type)), bodies_.erase(body)));
 }
 
 void NongroundProgramBuilder::edge(Location const &loc, TermVecVecUid edgesUid, BdLitVecUid body) {
     auto edges = termvecvecs_.erase(edgesUid);
-    for (auto it = edges.begin(), end = edges.end(), last = end-1; it != end; ++it) {
+    for (auto it = edges.begin(), end = edges.end(), last = end - 1; it != end; ++it) {
         prg_.add(make_locatable<Statement>(
-            loc,
-            make_locatable<EdgeHeadAtom>(
-                loc,
-                std::move(it->front()),
-                std::move(it->back())
-            ),
-            it == last ? bodies_.erase(body) : get_clone(bodies_[body])
-        ));
+            loc, make_locatable<EdgeHeadAtom>(loc, std::move(it->front()), std::move(it->back())),
+            it == last ? bodies_.erase(body) : get_clone(bodies_[body])));
     }
 }
 
-void NongroundProgramBuilder::heuristic(Location const &loc, TermUid termUid, BdLitVecUid body, TermUid a, TermUid b, TermUid mod) {
-    prg_.add(make_locatable<Statement>(loc, make_locatable<HeuristicHeadAtom>(loc, terms_.erase(termUid), terms_.erase(a), terms_.erase(b), terms_.erase(mod)), bodies_.erase(body)));
+void NongroundProgramBuilder::heuristic(Location const &loc, TermUid termUid, BdLitVecUid body, TermUid a, TermUid b,
+                                        TermUid mod) {
+    prg_.add(make_locatable<Statement>(loc,
+                                       make_locatable<HeuristicHeadAtom>(loc, terms_.erase(termUid), terms_.erase(a),
+                                                                         terms_.erase(b), terms_.erase(mod)),
+                                       bodies_.erase(body)));
 }
 
 void NongroundProgramBuilder::project(Location const &loc, TermUid termUid, BdLitVecUid body) {
-    prg_.add(make_locatable<Statement>(loc, make_locatable<ProjectHeadAtom>(loc, terms_.erase(termUid)), bodies_.erase(body)));
+    prg_.add(make_locatable<Statement>(loc, make_locatable<ProjectHeadAtom>(loc, terms_.erase(termUid)),
+                                       bodies_.erase(body)));
 }
 
 void NongroundProgramBuilder::project(Location const &loc, Sig sig) {
@@ -367,17 +358,20 @@ void NongroundProgramBuilder::project(Location const &loc, Sig sig) {
 
 TheoryTermUid NongroundProgramBuilder::theorytermset(Location const &loc, TheoryOptermVecUid args) {
     (void)loc;
-    return theoryTerms_.emplace(gringo_make_unique<Output::TupleTheoryTerm>(Output::TupleTheoryTerm::Type::Brace, theoryOptermVecs_.erase(args)));
+    return theoryTerms_.emplace(gringo_make_unique<Output::TupleTheoryTerm>(Output::TupleTheoryTerm::Type::Brace,
+                                                                            theoryOptermVecs_.erase(args)));
 }
 
 TheoryTermUid NongroundProgramBuilder::theoryoptermlist(Location const &loc, TheoryOptermVecUid args) {
     (void)loc;
-    return theoryTerms_.emplace(gringo_make_unique<Output::TupleTheoryTerm>(Output::TupleTheoryTerm::Type::Bracket, theoryOptermVecs_.erase(args)));
+    return theoryTerms_.emplace(gringo_make_unique<Output::TupleTheoryTerm>(Output::TupleTheoryTerm::Type::Bracket,
+                                                                            theoryOptermVecs_.erase(args)));
 }
 
 TheoryTermUid NongroundProgramBuilder::theorytermtuple(Location const &loc, TheoryOptermVecUid args) {
     (void)loc;
-    return theoryTerms_.emplace(gringo_make_unique<Output::TupleTheoryTerm>(Output::TupleTheoryTerm::Type::Paren, theoryOptermVecs_.erase(args)));
+    return theoryTerms_.emplace(gringo_make_unique<Output::TupleTheoryTerm>(Output::TupleTheoryTerm::Type::Paren,
+                                                                            theoryOptermVecs_.erase(args)));
 }
 
 TheoryTermUid NongroundProgramBuilder::theorytermopterm(Location const &loc, TheoryOptermUid opterm) {
@@ -413,36 +407,34 @@ TheoryOptermUid NongroundProgramBuilder::theoryopterm(TheoryOptermUid opterm, Th
     return opterm;
 }
 
-TheoryOpVecUid NongroundProgramBuilder::theoryops() {
-    return theoryOpVecs_.emplace();
-}
+TheoryOpVecUid NongroundProgramBuilder::theoryops() { return theoryOpVecs_.emplace(); }
 
 TheoryOpVecUid NongroundProgramBuilder::theoryops(TheoryOpVecUid ops, String op) {
     theoryOpVecs_[ops].emplace_back(op);
     return ops;
 }
 
-TheoryOptermVecUid NongroundProgramBuilder::theoryopterms() {
-    return theoryOptermVecs_.emplace();
-}
+TheoryOptermVecUid NongroundProgramBuilder::theoryopterms() { return theoryOptermVecs_.emplace(); }
 
-TheoryOptermVecUid NongroundProgramBuilder::theoryopterms(TheoryOptermVecUid opterms, Location const &loc, TheoryOptermUid opterm) {
+TheoryOptermVecUid NongroundProgramBuilder::theoryopterms(TheoryOptermVecUid opterms, Location const &loc,
+                                                          TheoryOptermUid opterm) {
     static_cast<void>(loc);
     theoryOptermVecs_[opterms].emplace_back(gringo_make_unique<Output::RawTheoryTerm>(theoryOpterms_.erase(opterm)));
     return opterms;
 }
 
-TheoryOptermVecUid NongroundProgramBuilder::theoryopterms(Location const &loc, TheoryOptermUid opterm, TheoryOptermVecUid opterms) {
+TheoryOptermVecUid NongroundProgramBuilder::theoryopterms(Location const &loc, TheoryOptermUid opterm,
+                                                          TheoryOptermVecUid opterms) {
     static_cast<void>(loc);
-    theoryOptermVecs_[opterms].insert(theoryOptermVecs_[opterms].begin(), gringo_make_unique<Output::RawTheoryTerm>(theoryOpterms_.erase(opterm)));
+    theoryOptermVecs_[opterms].insert(theoryOptermVecs_[opterms].begin(),
+                                      gringo_make_unique<Output::RawTheoryTerm>(theoryOpterms_.erase(opterm)));
     return opterms;
 }
 
-TheoryElemVecUid NongroundProgramBuilder::theoryelems() {
-    return theoryElems_.emplace();
-}
+TheoryElemVecUid NongroundProgramBuilder::theoryelems() { return theoryElems_.emplace(); }
 
-TheoryElemVecUid NongroundProgramBuilder::theoryelems(TheoryElemVecUid elems, TheoryOptermVecUid opterms, LitVecUid cond) {
+TheoryElemVecUid NongroundProgramBuilder::theoryelems(TheoryElemVecUid elems, TheoryOptermVecUid opterms,
+                                                      LitVecUid cond) {
     theoryElems_[elems].emplace_back(theoryOptermVecs_.erase(opterms), litvecs_.erase(cond));
     return elems;
 }
@@ -451,9 +443,11 @@ TheoryAtomUid NongroundProgramBuilder::theoryatom(TermUid term, TheoryElemVecUid
     return theoryAtoms_.emplace(terms_.erase(term), theoryElems_.erase(elems));
 }
 
-TheoryAtomUid NongroundProgramBuilder::theoryatom(TermUid term, TheoryElemVecUid elems, String op, Location const &loc, TheoryOptermUid opterm) {
+TheoryAtomUid NongroundProgramBuilder::theoryatom(TermUid term, TheoryElemVecUid elems, String op, Location const &loc,
+                                                  TheoryOptermUid opterm) {
     static_cast<void>(loc);
-    return theoryAtoms_.emplace(terms_.erase(term), theoryElems_.erase(elems), op, gringo_make_unique<Output::RawTheoryTerm>(theoryOpterms_.erase(opterm)));
+    return theoryAtoms_.emplace(terms_.erase(term), theoryElems_.erase(elems), op,
+                                gringo_make_unique<Output::RawTheoryTerm>(theoryOpterms_.erase(opterm)));
 }
 
 BdLitVecUid NongroundProgramBuilder::bodyaggr(BdLitVecUid body, Location const &loc, NAF naf, TheoryAtomUid atom) {
@@ -467,20 +461,20 @@ HdLitUid NongroundProgramBuilder::headaggr(Location const &loc, TheoryAtomUid at
 
 // {{{2 theory definitions
 
-TheoryOpDefUid NongroundProgramBuilder::theoryopdef(Location const &loc, String op, unsigned priority, TheoryOperatorType type) {
+TheoryOpDefUid NongroundProgramBuilder::theoryopdef(Location const &loc, String op, unsigned priority,
+                                                    TheoryOperatorType type) {
     return theoryOpDefs_.emplace(loc, op, priority, type);
 }
 
-TheoryOpDefVecUid NongroundProgramBuilder::theoryopdefs() {
-    return theoryOpDefVecs_.emplace();
-}
+TheoryOpDefVecUid NongroundProgramBuilder::theoryopdefs() { return theoryOpDefVecs_.emplace(); }
 
 TheoryOpDefVecUid NongroundProgramBuilder::theoryopdefs(TheoryOpDefVecUid defs, TheoryOpDefUid def) {
     theoryOpDefVecs_[defs].emplace_back(theoryOpDefs_.erase(def));
     return defs;
 }
 
-TheoryTermDefUid NongroundProgramBuilder::theorytermdef(Location const &loc, String name, TheoryOpDefVecUid defs, Logger &log) {
+TheoryTermDefUid NongroundProgramBuilder::theorytermdef(Location const &loc, String name, TheoryOpDefVecUid defs,
+                                                        Logger &log) {
     TheoryTermDef def(loc, name);
     for (auto &opDef : theoryOpDefVecs_.erase(defs)) {
         def.addOpDef(std::move(opDef), log);
@@ -488,17 +482,18 @@ TheoryTermDefUid NongroundProgramBuilder::theorytermdef(Location const &loc, Str
     return theoryTermDefs_.insert(std::move(def));
 }
 
-TheoryAtomDefUid NongroundProgramBuilder::theoryatomdef(Location const &loc, String name, unsigned arity, String termDef, TheoryAtomType type) {
+TheoryAtomDefUid NongroundProgramBuilder::theoryatomdef(Location const &loc, String name, unsigned arity,
+                                                        String termDef, TheoryAtomType type) {
     return theoryAtomDefs_.emplace(loc, name, arity, termDef, type);
 }
 
-TheoryAtomDefUid NongroundProgramBuilder::theoryatomdef(Location const &loc, String name, unsigned arity, String termDef, TheoryAtomType type, TheoryOpVecUid ops, String guardDef) {
+TheoryAtomDefUid NongroundProgramBuilder::theoryatomdef(Location const &loc, String name, unsigned arity,
+                                                        String termDef, TheoryAtomType type, TheoryOpVecUid ops,
+                                                        String guardDef) {
     return theoryAtomDefs_.emplace(loc, name, arity, termDef, type, theoryOpVecs_.erase(ops), guardDef);
 }
 
-TheoryDefVecUid NongroundProgramBuilder::theorydefs() {
-    return theoryDefVecs_.emplace();
-}
+TheoryDefVecUid NongroundProgramBuilder::theorydefs() { return theoryDefVecs_.emplace(); }
 
 TheoryDefVecUid NongroundProgramBuilder::theorydefs(TheoryDefVecUid defs, TheoryTermDefUid def) {
     theoryDefVecs_[defs].first.emplace_back(theoryTermDefs_.erase(def));
@@ -528,5 +523,5 @@ NongroundProgramBuilder::~NongroundProgramBuilder() noexcept = default;
 
 // }}}1
 
-} } // namespace Input Gringo
-
+} // namespace Input
+} // namespace Gringo
