@@ -22,19 +22,18 @@
 
 // }}}
 
-#include <gringo/input/theory.hh>
-#include <gringo/input/literals.hh>
 #include <gringo/ground/statements.hh>
+#include <gringo/input/literals.hh>
+#include <gringo/input/theory.hh>
 #include <gringo/logger.hh>
 
-namespace Gringo { namespace Input {
+namespace Gringo {
+namespace Input {
 
 // {{{1 definition of TheoryElement
 
 TheoryElement::TheoryElement(Output::UTheoryTermVec &&tuple, ULitVec &&cond)
-: tuple_(std::move(tuple))
-, cond_(std::move(cond))
-{ }
+    : tuple_(std::move(tuple)), cond_(std::move(cond)) {}
 
 bool TheoryElement::operator==(TheoryElement const &other) const {
     return is_value_equal_to(tuple_, other.tuple_) && is_value_equal_to(cond_, other.cond_);
@@ -43,8 +42,7 @@ bool TheoryElement::operator==(TheoryElement const &other) const {
 void TheoryElement::print(std::ostream &out) const {
     if (tuple_.empty() && cond_.empty()) {
         out << " : ";
-    }
-    else {
+    } else {
         print_comma(out, tuple_, ",", [](std::ostream &out, Output::UTheoryTerm const &term) { term->print(out); });
         if (!cond_.empty()) {
             out << ": ";
@@ -53,9 +51,7 @@ void TheoryElement::print(std::ostream &out) const {
     }
 }
 
-size_t TheoryElement::hash() const {
-    return get_value_hash(tuple_, cond_);
-}
+size_t TheoryElement::hash() const { return get_value_hash(tuple_, cond_); }
 
 bool TheoryElement::hasPool() const {
     for (auto const &lit : cond_) {
@@ -67,11 +63,9 @@ bool TheoryElement::hasPool() const {
 }
 
 void TheoryElement::unpool(TheoryElementVec &elems) {
-    Term::unpool(cond_.begin(), cond_.end(), [](ULit &lit) {
-        return lit->unpool(false);
-    }, [&](ULitVec &&cond) {
-        elems.emplace_back(get_clone(tuple_), std::move(cond));
-    });
+    Term::unpool(
+        cond_.begin(), cond_.end(), [](ULit &lit) { return lit->unpool(false); },
+        [&](ULitVec &&cond) { elems.emplace_back(get_clone(tuple_), std::move(cond)); });
 }
 
 bool TheoryElement::hasUnpoolComparison() const {
@@ -91,9 +85,7 @@ TheoryElementVec TheoryElement::unpoolComparison() {
     return ret;
 }
 
-TheoryElement TheoryElement::clone() const {
-    return {get_clone(tuple_), get_clone(cond_)};
-}
+TheoryElement TheoryElement::clone() const { return {get_clone(tuple_), get_clone(cond_)}; }
 
 void TheoryElement::replace(Defines &x) {
     for (auto &term : tuple_) {
@@ -179,7 +171,8 @@ void TheoryElement::initTheory(Output::TheoryParser &p, Logger &log) {
     }
 }
 
-std::unique_ptr<Ground::TheoryAccumulate> TheoryElement::toGround(ToGroundArg &x, Ground::TheoryComplete &completeRef, Ground::ULitVec &&lits) const {
+std::unique_ptr<Ground::TheoryAccumulate> TheoryElement::toGround(ToGroundArg &x, Ground::TheoryComplete &completeRef,
+                                                                  Ground::ULitVec &&lits) const {
     for (auto const &z : cond_) {
         lits.emplace_back(z->toGround(x.domains, false));
     }
@@ -189,30 +182,21 @@ std::unique_ptr<Ground::TheoryAccumulate> TheoryElement::toGround(ToGroundArg &x
 // {{{1 definition of TheoryAtom
 
 TheoryAtom::TheoryAtom(UTerm &&name, TheoryElementVec &&elems)
-: name_(std::move(name))
-, elems_(std::move(elems))
-, op_("")
-, guard_(nullptr)
-{ }
+    : name_(std::move(name)), elems_(std::move(elems)), op_(""), guard_(nullptr) {}
 
-TheoryAtom::TheoryAtom(UTerm &&name, TheoryElementVec &&elems, String op, Output::UTheoryTerm &&guard, TheoryAtomType type)
-: name_(std::move(name))
-, elems_(std::move(elems))
-, op_(op)
-, guard_(std::move(guard))
-, type_(type)
-{ }
+TheoryAtom::TheoryAtom(UTerm &&name, TheoryElementVec &&elems, String op, Output::UTheoryTerm &&guard,
+                       TheoryAtomType type)
+    : name_(std::move(name)), elems_(std::move(elems)), op_(op), guard_(std::move(guard)), type_(type) {}
 
 TheoryAtom TheoryAtom::clone() const {
-    return { get_clone(name_), get_clone(elems_), op_, hasGuard() ? get_clone(guard_) : nullptr, type_ };
+    return {get_clone(name_), get_clone(elems_), op_, hasGuard() ? get_clone(guard_) : nullptr, type_};
 }
 
-bool TheoryAtom::hasGuard() const {
-    return static_cast<bool>(guard_);
-}
+bool TheoryAtom::hasGuard() const { return static_cast<bool>(guard_); }
 
 bool TheoryAtom::operator==(TheoryAtom const &other) const {
-    bool ret = is_value_equal_to(name_, other.name_) && is_value_equal_to(elems_, other.elems_) && hasGuard() == other.hasGuard();
+    bool ret = is_value_equal_to(name_, other.name_) && is_value_equal_to(elems_, other.elems_) &&
+               hasGuard() == other.hasGuard();
     if (ret && hasGuard()) {
         ret = op_ == other.op_ && is_value_equal_to(guard_, other.guard_);
     }
@@ -241,12 +225,10 @@ size_t TheoryAtom::hash() const {
 
 bool TheoryAtom::hasPool() const {
     return name_->hasPool() ||
-           std::any_of(elems_.begin(), elems_.end(),
-                       [&](auto const &elem) { return elem.hasPool(); });
+           std::any_of(elems_.begin(), elems_.end(), [&](auto const &elem) { return elem.hasPool(); });
 }
 
-template <class T>
-void TheoryAtom::unpool(T f) {
+template <class T> void TheoryAtom::unpool(T f) {
     TheoryElementVec elems;
     for (auto &elem : elems_) {
         elem.unpool(elems);
@@ -259,15 +241,15 @@ void TheoryAtom::unpool(T f) {
 }
 
 bool TheoryAtom::hasUnpoolComparison() const {
-    return std::any_of(elems_.begin(), elems_.end(),
-                       [](auto const &elem) { return elem.hasUnpoolComparison(); });
+    return std::any_of(elems_.begin(), elems_.end(), [](auto const &elem) { return elem.hasUnpoolComparison(); });
 }
 
 void TheoryAtom::unpoolComparison() {
     // extract elements that need unpooling
     TheoryElementVec elems;
     move_if(elems_, elems, [](auto const &elem) {
-        return elem.hasUnpoolComparison();;
+        return elem.hasUnpoolComparison();
+        ;
     });
     // unpool conditions
     for (auto &elem : elems) {
@@ -281,7 +263,9 @@ void TheoryAtom::replace(Defines &x) {
     for (auto &elem : elems_) {
         elem.replace(x);
     }
-    if (hasGuard()) { guard_->replace(x); }
+    if (hasGuard()) {
+        guard_->replace(x);
+    }
 }
 
 void TheoryAtom::collect(VarTermBoundVec &vars) const {
@@ -342,7 +326,7 @@ void TheoryAtom::rewriteArithmetics(Term::ArithmeticsMap &arith, AuxGen &auxGen)
 
 void TheoryAtom::initTheory(Location const &loc, TheoryDefs &defs, bool inBody, bool hasBody, Logger &log) {
     Sig sig = name_->getSig();
-    for (auto &def : defs) {
+    for (auto const &def : defs) {
         if (auto const *atomDef = def.getAtomDef(sig)) {
             type_ = atomDef->type();
             if (inBody) {
@@ -358,8 +342,7 @@ void TheoryAtom::initTheory(Location const &loc, TheoryDefs &defs, bool inBody,
                         << "  " << sig << "\n";
                     return;
                 }
-            }
-            else {
+            } else {
                 if (type_ == TheoryAtomType::Body) {
                     GRINGO_REPORT(log, Warnings::RuntimeError)
                         << loc << ": error: theory head atom used in body:" << "\n"
@@ -375,8 +358,7 @@ void TheoryAtom::initTheory(Location const &loc, TheoryDefs &defs, bool inBody,
             }
             if (inBody) {
                 type_ = TheoryAtomType::Body;
-            }
-            else if (type_ != TheoryAtomType::Directive) {
+            } else if (type_ != TheoryAtomType::Directive) {
                 type_ = TheoryAtomType::Head;
             }
             if (auto const *termDef = def.getTermDef(atomDef->elemDef())) {
@@ -384,51 +366,42 @@ void TheoryAtom::initTheory(Location const &loc, TheoryDefs &defs, bool inBody,
                 for (auto &elem : elems_) {
                     elem.initTheory(p, log);
                 }
-            }
-            else {
-                GRINGO_REPORT(log, Warnings::RuntimeError)
-                    << loc << ": error: missing definition for term:" << "\n"
-                    << "  " << atomDef->elemDef() << "\n";
+            } else {
+                GRINGO_REPORT(log, Warnings::RuntimeError) << loc << ": error: missing definition for term:" << "\n"
+                                                           << "  " << atomDef->elemDef() << "\n";
             }
             if (hasGuard()) {
                 if (!atomDef->hasGuard()) {
-                    GRINGO_REPORT(log, Warnings::RuntimeError)
-                        << loc << ": error: unexpected guard:" << "\n"
-                        << "  " << sig << "\n";
-                }
-                else if (auto const *termDef = def.getTermDef(atomDef->guardDef())) {
+                    GRINGO_REPORT(log, Warnings::RuntimeError) << loc << ": error: unexpected guard:" << "\n"
+                                                               << "  " << sig << "\n";
+                } else if (auto const *termDef = def.getTermDef(atomDef->guardDef())) {
                     if (std::find(atomDef->ops().begin(), atomDef->ops().end(), op_) != atomDef->ops().end()) {
                         Output::TheoryParser p(loc, *termDef);
                         Term::replace(guard_, guard_->initTheory(p, log));
-                    }
-                    else {
+                    } else {
                         std::stringstream ss;
                         print_comma(ss, atomDef->ops(), ",");
-                        GRINGO_REPORT(log, Warnings::RuntimeError)
-                            << loc << ": error: unexpected operator:" << "\n"
-                            << "  " << op_ << "\n"
-                            << loc << ": note: expected one of:\n"
-                            << "  " << ss.str() << "\n";
+                        GRINGO_REPORT(log, Warnings::RuntimeError) << loc << ": error: unexpected operator:" << "\n"
+                                                                   << "  " << op_ << "\n"
+                                                                   << loc << ": note: expected one of:\n"
+                                                                   << "  " << ss.str() << "\n";
                     }
-                }
-                else {
-                    GRINGO_REPORT(log, Warnings::RuntimeError)
-                        << loc << ": error: missing definition for term:" << "\n"
-                        << "  " << atomDef->guardDef() << "\n";
+                } else {
+                    GRINGO_REPORT(log, Warnings::RuntimeError) << loc << ": error: missing definition for term:" << "\n"
+                                                               << "  " << atomDef->guardDef() << "\n";
                 }
             }
             return;
         }
     }
-    GRINGO_REPORT(log, Warnings::RuntimeError)
-        << loc << ": error: no definition found for theory atom:" << "\n"
-        << "  " << sig << "\n";
+    GRINGO_REPORT(log, Warnings::RuntimeError) << loc << ": error: no definition found for theory atom:" << "\n"
+                                               << "  " << sig << "\n";
 }
 
 CreateHead TheoryAtom::toGroundHead() {
     return [&](Ground::ULitVec &&lits) {
         for (auto &x : lits) {
-            auto *lit = dynamic_cast<Ground::TheoryLiteral*>(x.get());
+            auto *lit = dynamic_cast<Ground::TheoryLiteral *>(x.get());
             if (lit != nullptr && lit->auxiliary()) {
                 return gringo_make_unique<Ground::TheoryRule>(*lit, std::move(lits));
             }
@@ -439,12 +412,13 @@ CreateHead TheoryAtom::toGroundHead() {
 
 CreateBody TheoryAtom::toGroundBody(ToGroundArg &x, Ground::UStmVec &stms, NAF naf, UTerm &&id) const {
     if (hasGuard()) {
-        stms.emplace_back(gringo_make_unique<Ground::TheoryComplete>(x.domains, std::move(id), type_, get_clone(name_), op_, get_clone(guard_)));
+        stms.emplace_back(gringo_make_unique<Ground::TheoryComplete>(x.domains, std::move(id), type_, get_clone(name_),
+                                                                     op_, get_clone(guard_)));
+    } else {
+        stms.emplace_back(
+            gringo_make_unique<Ground::TheoryComplete>(x.domains, std::move(id), type_, get_clone(name_)));
     }
-    else {
-        stms.emplace_back(gringo_make_unique<Ground::TheoryComplete>(x.domains, std::move(id), type_, get_clone(name_)));
-    }
-    auto &completeRef = static_cast<Ground::TheoryComplete&>(*stms.back()); // NOLINT
+    auto &completeRef = static_cast<Ground::TheoryComplete &>(*stms.back()); // NOLINT
     CreateStmVec split;
     split.emplace_back([&completeRef](Ground::ULitVec &&lits) -> Ground::UStm {
         auto ret = gringo_make_unique<Ground::TheoryAccumulate>(completeRef, std::move(lits));
@@ -452,27 +426,24 @@ CreateBody TheoryAtom::toGroundBody(ToGroundArg &x, Ground::UStmVec &stms, NAF n
         return std::move(ret);
     });
     for (auto const &y : elems_) {
-        split.emplace_back([&completeRef,&y,&x](Ground::ULitVec &&lits) -> Ground::UStm {
+        split.emplace_back([&completeRef, &y, &x](Ground::ULitVec &&lits) -> Ground::UStm {
             auto ret = y.toGround(x, completeRef, std::move(lits));
             completeRef.addAccuDom(*ret);
             return std::move(ret);
         });
     }
     bool aux1 = type_ != TheoryAtomType::Body;
-    return {[&completeRef, naf, aux1](Ground::ULitVec &lits, bool primary, bool aux2) {
-        if (primary) {
-            auto ret = gringo_make_unique<Ground::TheoryLiteral>(completeRef, naf, aux1 || aux2);
-            lits.emplace_back(std::move(ret));
-        }
-    }, std::move(split)};
+    return {[&completeRef, naf, aux1](Ground::ULitVec &lits, bool aux2) {
+                auto ret = gringo_make_unique<Ground::TheoryLiteral>(completeRef, naf, aux1 || aux2);
+                lits.emplace_back(std::move(ret));
+            },
+            std::move(split)};
 }
 
 // {{{1 definition of HeadTheoryLiteral
 
 HeadTheoryLiteral::HeadTheoryLiteral(TheoryAtom &&atom, bool rewritten)
-: atom_(std::move(atom))
-, rewritten_(rewritten)
-{ }
+    : atom_(std::move(atom)), rewritten_(rewritten) {}
 
 CreateHead HeadTheoryLiteral::toGround(ToGroundArg &x, Ground::UStmVec &stms) const {
     static_cast<void>(x);
@@ -487,9 +458,7 @@ UHeadAggr HeadTheoryLiteral::rewriteAggregates(UBodyAggrVec &aggr) {
     return nullptr;
 }
 
-void HeadTheoryLiteral::collect(VarTermBoundVec &vars) const {
-    atom_.collect(vars);
-}
+void HeadTheoryLiteral::collect(VarTermBoundVec &vars) const { atom_.collect(vars); }
 
 void HeadTheoryLiteral::unpool(UHeadAggrVec &x) {
     atom_.unpool([&](TheoryAtom &&atom) { x.emplace_back(make_locatable<HeadTheoryLiteral>(loc(), std::move(atom))); });
@@ -505,33 +474,26 @@ bool HeadTheoryLiteral::simplify(Projections &project, SimplifyState &state, Log
     return atom_.simplify(project, state, log);
 }
 
-void HeadTheoryLiteral::assignLevels(AssignLevel &lvl) {
-    atom_.assignLevels(lvl);
-}
+void HeadTheoryLiteral::assignLevels(AssignLevel &lvl) { atom_.assignLevels(lvl); }
 
 void HeadTheoryLiteral::rewriteArithmetics(Term::ArithmeticsMap &arith, AuxGen &auxGen) {
     atom_.rewriteArithmetics(arith, auxGen);
 }
 
-bool HeadTheoryLiteral::hasPool() const {
-    return atom_.hasPool();
-}
+bool HeadTheoryLiteral::hasPool() const { return atom_.hasPool(); }
 
-void HeadTheoryLiteral::check(ChkLvlVec &lvl, Logger &log) const {
-    atom_.check(loc(), *this, lvl, log);
-}
+void HeadTheoryLiteral::check(ChkLvlVec &lvl, Logger &log) const { atom_.check(loc(), *this, lvl, log); }
 
-void HeadTheoryLiteral::replace(Defines &x) {
-    atom_.replace(x);
-}
+void HeadTheoryLiteral::replace(Defines &x) { atom_.replace(x); }
 
-size_t HeadTheoryLiteral::hash() const {
-    return atom_.hash();
-}
+size_t HeadTheoryLiteral::hash() const { return atom_.hash(); }
 
 void HeadTheoryLiteral::print(std::ostream &out) const {
-    if (rewritten_) { out << "#false"; }
-    else            { atom_.print(out); }
+    if (rewritten_) {
+        out << "#false";
+    } else {
+        atom_.print(out);
+    }
 }
 
 HeadTheoryLiteral *HeadTheoryLiteral::clone() const {
@@ -540,9 +502,8 @@ HeadTheoryLiteral *HeadTheoryLiteral::clone() const {
 }
 
 bool HeadTheoryLiteral::operator==(HeadAggregate const &other) const {
-    auto const *t = dynamic_cast<HeadTheoryLiteral const*>(&other);
-    return t != nullptr &&
-           atom_ == t->atom_;
+    auto const *t = dynamic_cast<HeadTheoryLiteral const *>(&other);
+    return t != nullptr && atom_ == t->atom_;
 }
 
 void HeadTheoryLiteral::initTheory(TheoryDefs &defs, bool hasBody, Logger &log) {
@@ -552,22 +513,16 @@ void HeadTheoryLiteral::initTheory(TheoryDefs &defs, bool hasBody, Logger &log)
 // {{{1 definition of BodyTheoryLiteral
 
 BodyTheoryLiteral::BodyTheoryLiteral(NAF naf, TheoryAtom &&atom, bool rewritten)
-: atom_(std::move(atom))
-, naf_(naf)
-, rewritten_(rewritten)
-{ }
+    : atom_(std::move(atom)), naf_(naf), rewritten_(rewritten) {}
 
-bool BodyTheoryLiteral::hasPool() const {
-    return atom_.hasPool();
-}
+bool BodyTheoryLiteral::hasPool() const { return atom_.hasPool(); }
 
 void BodyTheoryLiteral::unpool(UBodyAggrVec &x) {
-    atom_.unpool([&](TheoryAtom &&atom) { x.emplace_back(make_locatable<BodyTheoryLiteral>(loc(), naf_, std::move(atom))); });
+    atom_.unpool(
+        [&](TheoryAtom &&atom) { x.emplace_back(make_locatable<BodyTheoryLiteral>(loc(), naf_, std::move(atom))); });
 }
 
-bool BodyTheoryLiteral::hasUnpoolComparison() const {
-    return atom_.hasUnpoolComparison();
-}
+bool BodyTheoryLiteral::hasUnpoolComparison() const { return atom_.hasUnpoolComparison(); }
 
 UBodyAggrVecVec BodyTheoryLiteral::unpoolComparison() const {
     auto atom = atom_.clone();
@@ -583,13 +538,9 @@ bool BodyTheoryLiteral::simplify(Projections &project, SimplifyState &state, boo
     return atom_.simplify(project, state, log);
 }
 
-void BodyTheoryLiteral::assignLevels(AssignLevel &lvl) {
-    atom_.assignLevels(lvl);
-}
+void BodyTheoryLiteral::assignLevels(AssignLevel &lvl) { atom_.assignLevels(lvl); }
 
-void BodyTheoryLiteral::check(ChkLvlVec &lvl, Logger &log) const {
-    atom_.check(loc(), *this, lvl, log);
-}
+void BodyTheoryLiteral::check(ChkLvlVec &lvl, Logger &log) const { atom_.check(loc(), *this, lvl, log); }
 
 void BodyTheoryLiteral::rewriteArithmetics(Term::ArithmeticsMap &arith, Literal::RelationVec &assign, AuxGen &auxGen) {
     static_cast<void>(assign);
@@ -601,32 +552,26 @@ bool BodyTheoryLiteral::rewriteAggregates(UBodyAggrVec &aggr) {
     return true;
 }
 
-void BodyTheoryLiteral::removeAssignment() {
-}
+void BodyTheoryLiteral::removeAssignment() {}
 
-bool BodyTheoryLiteral::isAssignment() const {
-    return false;
-}
+bool BodyTheoryLiteral::isAssignment() const { return false; }
 
-void BodyTheoryLiteral::collect(VarTermBoundVec &vars) const {
-    atom_.collect(vars);
-}
+void BodyTheoryLiteral::collect(VarTermBoundVec &vars) const { atom_.collect(vars); }
 
-void BodyTheoryLiteral::replace(Defines &x) {
-    atom_.replace(x);
-}
+void BodyTheoryLiteral::replace(Defines &x) { atom_.replace(x); }
 
 CreateBody BodyTheoryLiteral::toGround(ToGroundArg &x, Ground::UStmVec &stms) const {
     return atom_.toGroundBody(x, stms, naf_, x.newId(*this));
 }
 
-size_t BodyTheoryLiteral::hash() const {
-    return get_value_hash(typeid(BodyTheoryLiteral).hash_code(), naf_, atom_);
-}
+size_t BodyTheoryLiteral::hash() const { return get_value_hash(typeid(BodyTheoryLiteral).hash_code(), naf_, atom_); }
 
 void BodyTheoryLiteral::print(std::ostream &out) const {
-    if (rewritten_) { out << "not " << atom_; }
-    else            { out << naf_ << atom_; }
+    if (rewritten_) {
+        out << "not " << atom_;
+    } else {
+        out << naf_ << atom_;
+    }
 }
 
 BodyTheoryLiteral *BodyTheoryLiteral::clone() const {
@@ -634,16 +579,13 @@ BodyTheoryLiteral *BodyTheoryLiteral::clone() const {
 }
 
 bool BodyTheoryLiteral::operator==(BodyAggregate const &other) const {
-    auto const *t = dynamic_cast<BodyTheoryLiteral const*>(&other);
-    return t != nullptr &&
-           naf_ == t->naf_ &&
-           atom_ == t->atom_;
+    auto const *t = dynamic_cast<BodyTheoryLiteral const *>(&other);
+    return t != nullptr && naf_ == t->naf_ && atom_ == t->atom_;
 }
 
-void BodyTheoryLiteral::initTheory(TheoryDefs &defs, Logger &log) {
-    atom_.initTheory(loc(), defs, true, true, log);
-}
+void BodyTheoryLiteral::initTheory(TheoryDefs &defs, Logger &log) { atom_.initTheory(loc(), defs, true, true, log); }
 
 // }}}1
 
-} } // namespace Gringo Input
+} // namespace Input
+} // namespace Gringo
