@@ -24,12 +24,13 @@
 
 #include "gringo/safetycheck.hh"
 
-#include "tests/tests.hh"
 #include "tests/term_helper.hh"
+#include "tests/tests.hh"
 
 #include <map>
 
-namespace Gringo { namespace Test {
+namespace Gringo {
+namespace Test {
 
 using namespace Gringo::IO;
 
@@ -42,20 +43,30 @@ typedef std::tuple<std::string, std::vector<std::string>, std::vector<std::strin
 
 std::string check(std::vector<T> list) {
     C dep;
-    std::unordered_map<std::string, C::VarNode*> vars;
-    auto iv = [&vars, &dep](std::string const &y) -> C::VarNode& {
+    std::unordered_map<std::string, C::VarNode *> vars;
+    auto iv = [&vars, &dep](std::string const &y) -> C::VarNode & {
         auto &pVar = vars[y];
-        if (!pVar) { pVar = &dep.insertVar(y); }
+        if (!pVar) {
+            pVar = &dep.insertVar(y);
+        }
         return *pVar;
     };
     for (auto &x : list) {
         auto &ent(dep.insertEnt(std::get<0>(x)));
-        for (auto &y : std::get<1>(x)) { dep.insertEdge(iv(y), ent); }
-        for (auto &y : std::get<2>(x)) { dep.insertEdge(ent, iv(y)); }
+        for (auto &y : std::get<1>(x)) {
+            dep.insertEdge(iv(y), ent);
+        }
+        for (auto &y : std::get<2>(x)) {
+            dep.insertEdge(ent, iv(y));
+        }
     }
     std::vector<std::string> order, open;
-    for (auto &x : dep.order()) { order.push_back(x->data); }
-    for (auto &x : dep.open()) { open.push_back(x->data); }
+    for (auto &x : dep.order()) {
+        order.push_back(x->data);
+    }
+    for (auto &x : dep.open()) {
+        open.push_back(x->data);
+    }
     std::sort(open.begin(), open.end());
     return to_string(std::make_pair(std::move(order), std::move(open)));
 }
@@ -66,13 +77,15 @@ std::string check(std::vector<T> list) {
 
 TEST_CASE("safetycheck", "[base]") {
     SECTION("safety") {
-        REQUIRE("([Y=1,X=Y],[])" == check({ T{"X=Y",{"Y"},{"X"}}, T{"Y=1",{},{"Y"}} }));
-        REQUIRE("([],[X,Y])" == check({ T{"0=X+Y",{"X","Y"}, {}} }));
-        REQUIRE("([A=1,B=A,C=B,D=C],[])" == check({ T{"A=1",{}, {"A"}}, T{"B=A",{"A"}, {"B"}}, T{"C=B",{"B"}, {"C"}}, T{"D=C",{"C"}, {"D"}} }));
-        REQUIRE("([],[A,B])" == check({ T{"A=B",{"B"}, {"A"}}, T{"B=A",{"A"}, {"B"}} }));
-        REQUIRE("([A=1,B=A,A=B],[])" == check({ T{"A=B",{"B"}, {"A"}}, T{"B=A",{"A"}, {"B"}}, T{"A=1",{}, {"A"}} }));
-        REQUIRE("([(X,Y)=(1,1),2=X+Y],[])" == check({ T{"(X,Y)=(1,1)",{}, {"X","Y"}}, T{"2=X+Y",{"X", "Y"}, {}} }));
+        REQUIRE("([Y=1,X=Y],[])" == check({T{"X=Y", {"Y"}, {"X"}}, T{"Y=1", {}, {"Y"}}}));
+        REQUIRE("([],[X,Y])" == check({T{"0=X+Y", {"X", "Y"}, {}}}));
+        REQUIRE("([A=1,B=A,C=B,D=C],[])" ==
+                check({T{"A=1", {}, {"A"}}, T{"B=A", {"A"}, {"B"}}, T{"C=B", {"B"}, {"C"}}, T{"D=C", {"C"}, {"D"}}}));
+        REQUIRE("([],[A,B])" == check({T{"A=B", {"B"}, {"A"}}, T{"B=A", {"A"}, {"B"}}}));
+        REQUIRE("([A=1,B=A,A=B],[])" == check({T{"A=B", {"B"}, {"A"}}, T{"B=A", {"A"}, {"B"}}, T{"A=1", {}, {"A"}}}));
+        REQUIRE("([(X,Y)=(1,1),2=X+Y],[])" == check({T{"(X,Y)=(1,1)", {}, {"X", "Y"}}, T{"2=X+Y", {"X", "Y"}, {}}}));
     }
 }
 
-} } // namespace Test Gringo
+} // namespace Test
+} // namespace Gringo
