@@ -25,14 +25,15 @@
 #include "gringo/utility.hh"
 #include "tests/tests.hh"
 
-namespace Gringo { namespace Test {
+namespace Gringo {
+namespace Test {
 
 using Gringo::IO::to_string;
 
 namespace {
 
 struct CloneMe {
-    CloneMe(int x) : x(x) { }
+    CloneMe(int x) : x(x) {}
     CloneMe(CloneMe const &) = delete;
     CloneMe(CloneMe &&) = default;
     CloneMe *clone() const { return new CloneMe(x); }
@@ -48,14 +49,14 @@ std::ostream &operator<<(std::ostream &out, CloneMe const &x) {
 
 TEST_CASE("utility", "[base]") {
     SECTION("to_string") {
-        int x1 { 1 };
-        std::unique_ptr<int> x2 { new int(1) };
-        std::pair<int, int> x3 { 1, 2 };
-        std::tuple<> x4 { };
-        std::tuple<int> x5 { 1 };
-        std::tuple<int,int,int> x6 { 1, 2, 3 };
-        std::vector<int> x7 { 1, 2, 3 };
-        std::vector<std::vector<int>> x8 { {1,2}, {3,4}, {5,6,7}, {8} };
+        int x1{1};
+        std::unique_ptr<int> x2{new int(1)};
+        std::pair<int, int> x3{1, 2};
+        std::tuple<> x4{};
+        std::tuple<int> x5{1};
+        std::tuple<int, int, int> x6{1, 2, 3};
+        std::vector<int> x7{1, 2, 3};
+        std::vector<std::vector<int>> x8{{1, 2}, {3, 4}, {5, 6, 7}, {8}};
 
         REQUIRE("1" == to_string(x1));
         REQUIRE("1" == to_string(x2));
@@ -68,15 +69,15 @@ TEST_CASE("utility", "[base]") {
     }
 
     SECTION("cross_product") {
-        std::vector<std::vector<int>> x1 { };
-        std::vector<std::vector<int>> x2 { {} };
-        std::vector<std::vector<int>> x3 { {1} };
-        std::vector<std::vector<int>> x4 { {1,2} };
-        std::vector<std::vector<int>> x5 { {1,2}, {3} };
-        std::vector<std::vector<int>> x6 { {1,2}, {3,4} };
-        std::vector<std::vector<int>> x7 { {1,2}, {3,4}, {} };
-        std::vector<std::vector<int>> x8 { {0,1}, {0,1}, {0,1} };
-        std::vector<std::vector<int>> x9 { {1,2}, {3,4}, {5,6,7}, {8} };
+        std::vector<std::vector<int>> x1{};
+        std::vector<std::vector<int>> x2{{}};
+        std::vector<std::vector<int>> x3{{1}};
+        std::vector<std::vector<int>> x4{{1, 2}};
+        std::vector<std::vector<int>> x5{{1, 2}, {3}};
+        std::vector<std::vector<int>> x6{{1, 2}, {3, 4}};
+        std::vector<std::vector<int>> x7{{1, 2}, {3, 4}, {}};
+        std::vector<std::vector<int>> x8{{0, 1}, {0, 1}, {0, 1}};
+        std::vector<std::vector<int>> x9{{1, 2}, {3, 4}, {5, 6, 7}, {8}};
         cross_product(x1);
         cross_product(x2);
         cross_product(x3);
@@ -94,20 +95,22 @@ TEST_CASE("utility", "[base]") {
         REQUIRE("[[1,3],[2,3],[1,4],[2,4]]" == to_string(x6));
         REQUIRE("[]" == to_string(x7));
         REQUIRE("[[0,0,0],[1,0,0],[0,1,0],[1,1,0],[0,0,1],[1,0,1],[0,1,1],[1,1,1]]" == to_string(x8));
-        REQUIRE("[[1,3,5,8],[2,3,5,8],[1,4,5,8],[2,4,5,8],[1,3,6,8],[2,3,6,8],[1,4,6,8],[2,4,6,8],[1,3,7,8],[2,3,7,8],[1,4,7,8],[2,4,7,8]]" == to_string(x9));
+        REQUIRE("[[1,3,5,8],[2,3,5,8],[1,4,5,8],[2,4,5,8],[1,3,6,8],[2,3,6,8],[1,4,6,8],[2,4,6,8],[1,3,7,8],[2,3,7,8],["
+                "1,4,7,8],[2,4,7,8]]" == to_string(x9));
     }
 
     SECTION("clone") {
         typedef std::unique_ptr<CloneMe> U;
-        CloneMe x1 { 1 };
+        CloneMe x1{1};
         auto x2(gringo_make_unique<CloneMe>(1));
         auto x3(std::make_pair(gringo_make_unique<CloneMe>(1), gringo_make_unique<CloneMe>(2)));
         std::vector<U> x4;
         x4.emplace_back(gringo_make_unique<CloneMe>(1));
         x4.emplace_back(gringo_make_unique<CloneMe>(2));
         x4.emplace_back(gringo_make_unique<CloneMe>(3));
-        std::tuple<U, U, U> x5 { gringo_make_unique<CloneMe>(1), gringo_make_unique<CloneMe>(2), gringo_make_unique<CloneMe>(3) };
-        std::tuple<> x6 { };
+        std::tuple<U, U, U> x5{gringo_make_unique<CloneMe>(1), gringo_make_unique<CloneMe>(2),
+                               gringo_make_unique<CloneMe>(3)};
+        std::tuple<> x6{};
         REQUIRE(to_string(1) == to_string(get_clone(1)));
         REQUIRE(to_string(x1) == to_string(U(get_clone(&x1))));
         REQUIRE(to_string(x2) == to_string(get_clone(x2)));
@@ -118,30 +121,32 @@ TEST_CASE("utility", "[base]") {
     }
 
     SECTION("hash") {
-        std::vector<int> x1 { };
-        std::vector<int> x1e { };
-        std::vector<int> x2 { 1, 2, 3 };
-        std::vector<int> x2e { 1, 2, 3 };
-        std::vector<int> x3 { 1, 2, 3, 4 };
-        std::vector<int> x3e { 1, 2, 3, 4 };
-        std::pair<int, int> x4 { 1, 2 };
-        std::pair<int, int> x4e { 1, 2 };
-        std::pair<int, int> x5 { 2, 3 };
-        std::pair<int, int> x5e { 2, 3 };
-        std::tuple<> x6 { };
-        std::tuple<> x6e { };
-        std::tuple<int, int, int> x7 { 1, 2, 4 };
-        std::tuple<int, int, int> x7e { 1, 2, 4 };
-        std::tuple<int, int, int> x8 { 1, 2, 3 };
-        std::tuple<int, int, int> x8e { 1, 2, 3 };
-        std::unique_ptr<int> x9 { new int(1) };
-        std::unique_ptr<int> x9e { new int(1) };
-        std::unique_ptr<int> x10 { new int(2) };
-        std::unique_ptr<int> x10e { new int(2) };
-        std::tuple<std::pair<std::vector<int>, std::unique_ptr<int>>> x11 { std::make_pair(std::vector<int> {1, 2, 3}, gringo_make_unique<int>(4)) };
-        std::tuple<std::pair<std::vector<int>, std::unique_ptr<int>>> x11e { std::make_pair(std::vector<int> {1, 2, 3}, gringo_make_unique<int>(4)) };
-        std::tuple<std::pair<std::vector<int>, std::unique_ptr<int>>> x12 { std::make_pair(std::vector<int> {1, 2, 4}, gringo_make_unique<int>(4)) };
-
+        std::vector<int> x1{};
+        std::vector<int> x1e{};
+        std::vector<int> x2{1, 2, 3};
+        std::vector<int> x2e{1, 2, 3};
+        std::vector<int> x3{1, 2, 3, 4};
+        std::vector<int> x3e{1, 2, 3, 4};
+        std::pair<int, int> x4{1, 2};
+        std::pair<int, int> x4e{1, 2};
+        std::pair<int, int> x5{2, 3};
+        std::pair<int, int> x5e{2, 3};
+        std::tuple<> x6{};
+        std::tuple<> x6e{};
+        std::tuple<int, int, int> x7{1, 2, 4};
+        std::tuple<int, int, int> x7e{1, 2, 4};
+        std::tuple<int, int, int> x8{1, 2, 3};
+        std::tuple<int, int, int> x8e{1, 2, 3};
+        std::unique_ptr<int> x9{new int(1)};
+        std::unique_ptr<int> x9e{new int(1)};
+        std::unique_ptr<int> x10{new int(2)};
+        std::unique_ptr<int> x10e{new int(2)};
+        std::tuple<std::pair<std::vector<int>, std::unique_ptr<int>>> x11{
+            std::make_pair(std::vector<int>{1, 2, 3}, gringo_make_unique<int>(4))};
+        std::tuple<std::pair<std::vector<int>, std::unique_ptr<int>>> x11e{
+            std::make_pair(std::vector<int>{1, 2, 3}, gringo_make_unique<int>(4))};
+        std::tuple<std::pair<std::vector<int>, std::unique_ptr<int>>> x12{
+            std::make_pair(std::vector<int>{1, 2, 4}, gringo_make_unique<int>(4))};
 
         REQUIRE(get_value_hash(1) == get_value_hash(1));
         REQUIRE(get_value_hash(x1) == get_value_hash(x1e));
@@ -168,29 +173,32 @@ TEST_CASE("utility", "[base]") {
     }
 
     SECTION("equal_to") {
-        std::vector<int> x1 { };
-        std::vector<int> x1e { };
-        std::vector<int> x2 { 1, 2, 3 };
-        std::vector<int> x2e { 1, 2, 3 };
-        std::vector<int> x3 { 1, 2, 3, 4 };
-        std::vector<int> x3e { 1, 2, 3, 4 };
-        std::pair<int, int> x4 { 1, 2 };
-        std::pair<int, int> x4e { 1, 2 };
-        std::pair<int, int> x5 { 2, 3 };
-        std::pair<int, int> x5e { 2, 3 };
-        std::tuple<> x6 { };
-        std::tuple<> x6e { };
-        std::tuple<int, int, int> x7 { 1, 2, 4 };
-        std::tuple<int, int, int> x7e { 1, 2, 4 };
-        std::tuple<int, int, int> x8 { 1, 2, 3 };
-        std::tuple<int, int, int> x8e { 1, 2, 3 };
-        std::unique_ptr<int> x9 { new int(1) };
-        std::unique_ptr<int> x9e { new int(1) };
-        std::unique_ptr<int> x10 { new int(2) };
-        std::unique_ptr<int> x10e { new int(2) };
-        std::tuple<std::pair<std::vector<int>, std::unique_ptr<int>>> x11 { std::make_pair(std::vector<int> {1, 2, 3}, gringo_make_unique<int>(4)) };
-        std::tuple<std::pair<std::vector<int>, std::unique_ptr<int>>> x11e { std::make_pair(std::vector<int> {1, 2, 3}, gringo_make_unique<int>(4)) };
-        std::tuple<std::pair<std::vector<int>, std::unique_ptr<int>>> x12 { std::make_pair(std::vector<int> {1, 2, 4}, gringo_make_unique<int>(4)) };
+        std::vector<int> x1{};
+        std::vector<int> x1e{};
+        std::vector<int> x2{1, 2, 3};
+        std::vector<int> x2e{1, 2, 3};
+        std::vector<int> x3{1, 2, 3, 4};
+        std::vector<int> x3e{1, 2, 3, 4};
+        std::pair<int, int> x4{1, 2};
+        std::pair<int, int> x4e{1, 2};
+        std::pair<int, int> x5{2, 3};
+        std::pair<int, int> x5e{2, 3};
+        std::tuple<> x6{};
+        std::tuple<> x6e{};
+        std::tuple<int, int, int> x7{1, 2, 4};
+        std::tuple<int, int, int> x7e{1, 2, 4};
+        std::tuple<int, int, int> x8{1, 2, 3};
+        std::tuple<int, int, int> x8e{1, 2, 3};
+        std::unique_ptr<int> x9{new int(1)};
+        std::unique_ptr<int> x9e{new int(1)};
+        std::unique_ptr<int> x10{new int(2)};
+        std::unique_ptr<int> x10e{new int(2)};
+        std::tuple<std::pair<std::vector<int>, std::unique_ptr<int>>> x11{
+            std::make_pair(std::vector<int>{1, 2, 3}, gringo_make_unique<int>(4))};
+        std::tuple<std::pair<std::vector<int>, std::unique_ptr<int>>> x11e{
+            std::make_pair(std::vector<int>{1, 2, 3}, gringo_make_unique<int>(4))};
+        std::tuple<std::pair<std::vector<int>, std::unique_ptr<int>>> x12{
+            std::make_pair(std::vector<int>{1, 2, 4}, gringo_make_unique<int>(4))};
 
         REQUIRE(is_value_equal_to(x1, x1e));
         REQUIRE(is_value_equal_to(x2, x2e));
@@ -214,5 +222,5 @@ TEST_CASE("utility", "[base]") {
     }
 }
 
-} } // namespace Test Gringo
-
+} // namespace Test
+} // namespace Gringo
