@@ -270,6 +270,11 @@ statement = Rule
                                           )?
                            )*
              )
+          | Comment
+             ( location     : Location
+             , value        : str
+             , comment_type : CommentType
+             )
 ```
 
 Examples
@@ -312,7 +317,9 @@ The next example shows how to transform ASTs using the `Transformer` class:
     p(_X) :- q(_X).
 """
 
+from collections import abc
 from enum import IntEnum
+from functools import total_ordering
 from typing import (
     Any,
     Callable,
@@ -326,24 +333,22 @@ from typing import (
     Tuple,
     Union,
 )
-from collections import abc
-from functools import total_ordering
 
 from ._internal import (
+    _c_call,
+    _cb_error_handler,
     _CBData,
     _Error,
-    _cb_error_handler,
-    _c_call,
     _ffi,
     _handle_error,
     _lib,
     _str,
     _to_str,
 )
-from .util import Slice, SlicedMutableSequence
-from .core import Logger, OrderedEnum
 from .control import Control
+from .core import Logger, OrderedEnum
 from .symbol import Symbol
+from .util import Slice, SlicedMutableSequence
 
 __all__ = [
     "AST",
@@ -358,6 +363,8 @@ __all__ = [
     "BodyAggregate",
     "BodyAggregateElement",
     "BooleanConstant",
+    "Comment",
+    "CommentType",
     "Comparison",
     "ComparisonOperator",
     "ConditionalLiteral",
@@ -387,6 +394,7 @@ __all__ = [
     "ShowTerm",
     "Sign",
     "StrSequence",
+    "SymbolicAtom",
     "SymbolicTerm",
     "TheoryAtom",
     "TheoryAtomDefinition",
@@ -464,6 +472,7 @@ class ASTType(OrderedEnum):
     ProjectSignature = _lib.clingo_ast_type_project_signature
     Defined = _lib.clingo_ast_type_defined
     TheoryDefinition = _lib.clingo_ast_type_theory_definition
+    Comment = _lib.clingo_ast_type_comment
 
 
 class AggregateFunction(IntEnum):
@@ -536,6 +545,21 @@ class BinaryOperator(IntEnum):
     """
 
 
+class CommentType(IntEnum):
+    """
+    Enumeration of comment types.
+    """
+
+    Line = _lib.clingo_comment_type_line
+    """
+    Line comments starting with `%` ending at a newline.
+    """
+    Block = _lib.clingo_comment_type_block
+    """
+    Block comments enclosed in `%*` and  `*%`.
+    """
+
+
 class ComparisonOperator(IntEnum):
     """
     Enumeration of comparison operators.
@@ -669,6 +693,10 @@ class UnaryOperator(IntEnum):
 class ASTSequence(abc.MutableSequence):
     """
     A sequence holding `AST` nodes.
+
+    Sequences implement Python's rich comparison operators and are ordered
+    structurally ignoring the location. They can also be used as dictionary
+    keys.
     """
 
     def __init__(self, rep, attribute):
@@ -676,6 +704,15 @@ class ASTSequence(abc.MutableSequence):
         self._attribute = attribute
         _lib.clingo_ast_acquire(self._rep)
 
+    def __eq__(self, other):
+        return tuple(self) == tuple(other)
+
+    def __lt__(self, other):
+        return tuple(self) < tuple(other)
+
+    def __hash__(self):
+        return hash(tuple(self))
+
     def __del__(self):
         _lib.clingo_ast_release(self._rep)
 
@@ -1215,7 +1252,7 @@ def _pyclingo_ast_callback(ast, data):
 def parse_files(
     files: Sequence[str],
     callback: Callable[[AST], None],
-    control: Control = None,
+    control: Optional[Control] = None,
     logger: Optional[Logger] = None,
     message_limit: int = 20,
 ) -> None:
@@ -1278,7 +1315,7 @@ def parse_files(
 def parse_string(
     program: str,
     callback: Callable[[AST], None],
-    control: Control = None,
+    control: Optional[Control] = None,
     logger: Optional[Logger] = None,
     message_limit: int = 20,
 ) -> None:
@@ -2336,3 +2373,21 @@ def TheoryDefinition(
         )
     )
     return AST(p_ast[0])
+
+
+def Comment(location: Location, value: str, comment_type: int) -> AST:
+    """
+    Construct an AST node of type `ASTType.Comment`.
+    """
+    p_ast = _ffi.new("clingo_ast_t**")
+    c_location = _c_location(location)
+    _handle_error(
+        _lib.clingo_ast_build(
+            _lib.clingo_ast_type_comment,
+            p_ast,
+            c_location[0],
+            _ffi.new("char const[]", value.encode()),
+            _ffi.cast("int", comment_type),
+        )
+    )
+    return AST(p_ast[0])
