@@ -37,12 +37,11 @@ The following example shows how to solve asynchronously:
     >>> from clingo import Control
     >>>
     >>> ctl = Control(["0"])
-    >>> ctl = clingo.Control("0")
     >>> ctl.add("base", [], "1 { a; b } 1.")
     >>> ctl.ground([("base", [])])
     >>> with ctl.solve(on_model=print, async_=True) as hnd:
     ...     # some computation here
-    ...     hnd.wait():
+    ...     hnd.wait()
     ...     print(hnd.get())
     ...
     Answer: a
@@ -54,7 +53,6 @@ This example shows how to solve both iteratively and asynchronously:
     >>> from clingo import Control
     >>>
     >>> ctl = Control(["0"])
-    >>> ctl.configuration.solve.models = 0
     >>> ctl.add("base", [], "1 { a; b } 1.")
     >>> ctl.ground([("base", [])])
     >>> with ctl.solve(yield_=True, async_=True) as hnd:
@@ -76,10 +74,10 @@ This example shows how to solve both iteratively and asynchronously:
 from typing import ContextManager, Iterator, List, Optional, Sequence, Tuple, Union
 
 from ._internal import _c_call, _c_call2, _ffi, _handle_error, _lib
-from .util import Slice, SlicedSequence
 from .core import OrderedEnum
 from .symbol import Symbol
 from .symbolic_atoms import SymbolicAtoms
+from .util import Slice, SlicedSequence
 
 __all__ = ["Model", "ModelType", "SolveControl", "SolveHandle", "SolveResult"]
 
@@ -341,6 +339,38 @@ class Model:
         """
         return _c_call("bool", _lib.clingo_model_is_true, self._rep, literal)
 
+    def is_consequence(self, literal: int) -> Optional[bool]:
+        """
+        Check if the given program literal is a consequence.
+
+        The function returns `True`, `False`, or `None` if the literal is a
+        consequence, not a consequence, or it is not yet known whether it is a
+        consequence, respectively.
+
+        While enumerating cautious or brave consequences, there is partial
+        information about which literals are consequences. The current state of
+        a literal can be requested using this function. If this function is
+        used during normal model enumeration, the function just returns whether
+        a literal is true of false in the current model.
+
+        Parameters
+        ----------
+        literal
+            The given program literal.
+
+        Returns
+        -------
+        Whether the given program literal is a consequence.
+        """
+        res = _c_call(
+            "clingo_consequence_t", _lib.clingo_model_is_consequence, self._rep, literal
+        )
+        if res == _lib.clingo_consequence_true:
+            return True
+        if res == _lib.clingo_consequence_false:
+            return False
+        return None
+
     def symbols(
         self,
         atoms: bool = False,
@@ -424,6 +454,18 @@ class Model:
 
         return list(p_costs)
 
+    @property
+    def priority(self) -> List[int]:
+        """
+        Return the priorities of the model's cost values.
+        """
+        size = _c_call("size_t", _lib.clingo_model_cost_size, self._rep)
+
+        p_priorities = _ffi.new("clingo_weight_t[]", size)
+        _handle_error(_lib.clingo_model_priority(self._rep, p_priorities, size))
+
+        return list(p_priorities)
+
     @property
     def number(self) -> int:
         """
@@ -517,6 +559,20 @@ class SolveHandle(ContextManager["SolveHandle"]):
         )
         return [core[i] for i in range(size)]
 
+    def last(self) -> Optional[Model]:
+        """
+        The last computed model if there is any.
+
+        Notes
+        -----
+        If the search is not completed yet or the problem is unsatisfiable, the function returns None.
+        """
+        p_model = _ffi.new("clingo_model_t**")
+        _handle_error(_lib.clingo_solve_handle_last(self._rep, p_model), self._handler)
+        if p_model[0] == _ffi.NULL:
+            return None
+        return Model(p_model[0])
+
     def get(self) -> SolveResult:
         """
         Get the result of a solve call.
