@@ -5,9 +5,9 @@ Helpers to simplify testing.
 from typing import List, cast
 from unittest import TestCase
 
-from ..control import Control
-from ..configuration import Configuration
 from .. import SolveResult, parse_term
+from ..configuration import Configuration
+from ..control import Control
 
 
 def _p(*models):
@@ -20,6 +20,7 @@ class _MCB:
         self._models = []
         self._core = None
         self.last = None
+        self.final = None
 
     def on_core(self, c):
         self._core = c
@@ -28,6 +29,10 @@ class _MCB:
         self.last = (m.type, sorted(m.symbols(shown=True)))
         self._models.append(self.last[1])
 
+    def on_last(self, m):
+        assert self.final is None
+        self.final = (m.type, sorted(m.symbols(shown=True)))
+
     @property
     def core(self):
         return sorted(self._core)
