@@ -32,16 +32,18 @@ extern "C" {
 #endif
 
 #if defined(_WIN32)
-#  define CFFI_DLLEXPORT  __declspec(dllexport)
+#define CFFI_DLLEXPORT __declspec(dllexport)
 #elif defined(__GNUC__)
-#  define CFFI_DLLEXPORT  __attribute__((visibility("default")))
+#define CFFI_DLLEXPORT __attribute__((visibility("default")))
 #else
-#  define CFFI_DLLEXPORT  /* nothing */
+#define CFFI_DLLEXPORT /* nothing */
 #endif
 
 CFFI_DLLEXPORT bool pyclingo_execute(clingo_location_t const *loc, char const *code, void *);
-CFFI_DLLEXPORT bool pyclingo_call(clingo_location_t const *loc, char const *name, clingo_symbol_t const *arguments, size_t size, clingo_symbol_callback_t symbol_callback, void *symbol_callback_data, void *);
-CFFI_DLLEXPORT bool pyclingo_callable(char const * name, bool *ret, void *);
+CFFI_DLLEXPORT bool pyclingo_call(clingo_location_t const *loc, char const *name, clingo_symbol_t const *arguments,
+                                  size_t size, clingo_symbol_callback_t symbol_callback, void *symbol_callback_data,
+                                  void *);
+CFFI_DLLEXPORT bool pyclingo_callable(char const *name, bool *ret, void *);
 CFFI_DLLEXPORT bool pyclingo_main(clingo_control_t *ctl, void *);
 bool clingo_register_python_();
 
